/* MinWin Label class
 *
 * Static text label 
 *
 * Written by Ben Hinkle and released to the public domain, as
 * explained at http://creativecommons.org/licenses/publicdomain
 * Email comments and bug reports to ben.hinkle@gmail.com
 */

module minwin.label;

import minwin.component;

private {
  import minwin.app;
  import minwin.window;
  import minwin.peerimpl;
  import std.string;
  import minwin.logging;
}

version (Windows) {

  private import minwin.mswindows;

  template LabelPrefSizeImpl() {
    Point preferredSize() {
      HDC dc = GetDC(peer);
      sysAssert(dc !is null, "Failed to get label DC in preferredSize");
      SIZE s;
      try {
	Font f = standardFont(StandardFont.Gui);
	HFONT oldfont = SelectObject(dc,f.peer);
	sysAssert(oldfont !is null, "Failed to get Label font in preferredSize");
	BOOL ok = GetTextExtentPoint32A(dc,text_data.ptr,text_data.length,&s);
	SelectObject(dc,oldfont);
	sysAssert(ok != false, "Failed to get font extents in preferredSize");
      } finally {
	ReleaseDC(peer,dc);
      }
      POINT p;
      p.x = s.cx;
      p.y = s.cy;
      if (userPreferredWidth > 0)
	p.x = userPreferredWidth;
      if (userPreferredHeight > 0)
	p.y = userPreferredHeight;
      return toPoint(p);
    }
  }

  class Label : WindowChild {
    char[] text_data;
    this(Component parent, char[] text, char[] name = "") {
      PeerForAdd parentp = parent.getPeerForAdd();
      peer = CreateWindowA("STATIC",toStringz(text),
			   SS_LEFTNOWORDWRAP | WS_CHILD | WS_VISIBLE,
			   0,0,10,10,parentp,
			   cast(HMENU)0,gApp.hInstance,null);
      sysAssert(peer !is null, "Failed to create peer Label");
      this.name = name;
      text_data = text;
      Font f = standardFont(StandardFont.Gui);
      SendMessageA(peer,WM_SETFONT,cast(WPARAM)f.peer,0);
      setWindowChildPeer(this,peer,OWNS_PEER);
      parent.addChild(this);
    }
    mixin LabelPrefSizeImpl!();
    mixin WindowChildImpl!();
  }

} version (Motif) {

  private import minwin.motif;

  class Label : WindowChild {
    this(Component parent, char[] text, char[] name = "") {
      PeerForAdd parentp = parent.getPeerForAdd();
      this.name = name;
      char* str = toStringz(text);
      XmString xmstr = XmStringCreate(str,XmFONTLIST_DEFAULT_TAG);
      Arg[6] args;
      int n;
      XtSetArg(args[n],XmNlabelString,cast(XtArgVal)xmstr);n++;
      //      XtSetArg(args[0],XmNlabelString,cast(XtArgVal)str);n++;
      peer = XmCreateLabel(parentp,toStringz(name),args,n);
      XmStringFree(xmstr);
      setWindowChildPeer(this,peer,OWNS_PEER);
      parent.addChild(this);
      XtManageChild(peer);
      XtRealizeWidget(peer);
    }
    char[] text() {
      /*
      char* str = toStringz(c);
      XmString xmstr = XmStringCreate(str,XmFONTLIST_DEFAULT_TAG);
      Arg[6] args;
      int n;
      XtSetArg(args[n],XmNlabelString,cast(XtArgVal)&xmstr);n++;
      XtGetValues(peer,args.ptr,n);
      XmStringFree(xmstr);
      return buf[0..len].dup;
      */
      return "";
    }
    void text(char[] c) {
      char* str = toStringz(c);
      XmString xmstr = XmStringCreate(str,XmFONTLIST_DEFAULT_TAG);
      Arg[6] args;
      int n;
      XtSetArg(args[n],XmNlabelString,cast(XtArgVal)xmstr);n++;
      XtSetValues(peer,args.ptr,n);
      XmStringFree(xmstr);
    }
    mixin WindowChildImpl!();
  }

} version (GTK) {

  private import minwin.gtk;

  class Label : WindowChild {
    this(Component parent, char[] text, char[] name = "") {
      PeerForAdd parentp = parent.getPeerForAdd();
      this.name = name;
      char* str = toStringz(text);
      peer = gtk_label_new(str);
      gtk_container_add(cast(GtkContainer*)parentp,peer);
      setWindowChildPeer(this,peer,OWNS_PEER);
      parent.addChild(this);
      gtk_widget_realize(peer);
      visible = true;
    }

    mixin WindowChildImpl!();

    char[] text() {
      char* str = gtk_label_get_text(cast(GtkLabel*)peer);
      if (str is null)
	return null;
      else
	return str[0..strlen(str)].dup;
    }

    void text(char[] c) {
      gtk_label_set_text(cast(GtkLabel*)peer,g_strdup(c.ptr));
    }
  }
}
