
module minwin.menu;

import minwin.window;
private {
  import minwin.app;
  import std.string;
}

// todo: disposePeer?

version (Windows) {
  private import minwin.mswindows;
  alias HMENU MenuPeer;
  alias HMENU MenuBarPeer;

  class MenuBar {
    MenuBarPeer peer;
    char[] name;
    Window owner;
    Menu[] menus;

    this(Window parent, char[] name = "") {
      peer = CreateMenu();
      BOOL ok = SetMenu(parent.peer,peer); // destroy old menu?
      sysAssert(ok != false, "Failed to set menu");
      owner = parent;
      owner.menubar = this;
      this.name = name;
    }
  }
  
  class Menu {
    MenuPeer peer;
    char[] name;

    this(inout MenuBar bar, char[] label, char[] name = "") {
      this.name = name;
      peer = CreateMenu();
      BOOL ok = AppendMenuA(bar.peer,MF_POPUP,cast(void*)peer,toStringz(label));
      sysAssert(ok != false, "Failed to append to menubar");
      bar.menus ~= this;
      ok = DrawMenuBar(bar.owner.peer);
      sysAssert(ok != false, "Failed to draw menu bar");
    }
    void addSeparator() {
      BOOL ok = AppendMenuA(peer,MF_SEPARATOR,null,null);
      sysAssert(ok != false, "Failed to append separator to menu");
    }
    void add(char[] name, int cmd) {
      BOOL ok = AppendMenuA(peer,MF_STRING,cast(void*)(cmd),
		 toStringz(name));
      sysAssert(ok != false, "Failed to append to menu");
    }
  }
} else version (Motif) {

  private import minwin.motif;

  alias minwin.window.Window mwWindow;

  alias Widget MenuPeer;
  alias Widget MenuBarPeer;

  class MenuBar {
    MenuBarPeer peer;
    char[] name;
    mwWindow owner;
    Menu[] menus;

    this(mwWindow parent, char[] name = "") {
      this.name = name;
      char*cstr = toStringz(name);
      peer = XmCreateMenuBar(parent.getPeerForAdd(),cstr,null,0);
      XtManageChild(peer);
      owner = parent;
      owner.menubar = this;
    }
  }
  
  class Menu {
    MenuPeer peer;
    char[] name;
    MenuBar parentBar;
    Widget trigger;

    this(inout MenuBar bar, char[] label, char[] name = "") {
      this.name = name;
      char* cname = toStringz(label);
      peer = XmCreatePulldownMenu(bar.peer,cname,null,0);
      Arg[4] args;
      int n;
      XtSetArg(args[n],XmNsubMenuId,cast(XtArgVal)peer); n++;
      XmString xmstr = XmStringCreateLocalized(cname);
      XtSetArg(args[n],XmNlabelString,cast(XtArgVal)xmstr); n++;
      trigger = XmCreateCascadeButton(bar.peer,cname,args,n);
      XtManageChild(trigger);
      XmStringFree(xmstr);
      bar.menus ~= this;
      parentBar = bar;
    }

    void addSeparator() {
      Widget item = XmCreateSeparator(peer,"Separator",null,0);
      XtManageChild(item);
      XtSetSensitive(item,true);
    }

    void add(char[] name, int cmd) {
      char* cname = toStringz(name);
      Arg[4] args;
      int n;
      XmString xmstr = XmStringCreateLocalized(cname);
      XtSetArg(args[n],XmNlabelString,cast(XtArgVal)xmstr); n++;
      XtSetArg(args[n],XmNuserData,cast(XtArgVal)cmd); n++;
      Widget item = XmCreatePushButton(peer,cname,args,n);
      XtAddCallback(item,XmNactivateCallback, &mw_menuitem_callback,cast(XPointer)parentBar.owner);
      XtManageChild(item);
      XtSetSensitive(item,true);
      XmStringFree(xmstr);
    }

    void enableItem(int n, bool on) {
      //      XtSetSensitive(item,on);
    }

  }
  extern (C)
    void mw_menuitem_callback(Widget w, XtPointer ud, XEvent* cbs) {
    mwWindow x = cast(mwWindow)ud;
    if (x) {
      Arg[4] args;
      int n,cmd;
      XtSetArg(args[n],XmNuserData,cast(XtArgVal)&cmd); n++;
      XtGetValues(w,args,n);
      x.doCommand(cmd);
    }
  }
  
} else version (GTK) {

  private import minwin.gtk;

  alias GtkWidget* MenuPeer;
  alias GtkWidget* MenuBarPeer;

  class MenuBar {
    MenuBarPeer peer;
    char[] name;
    Window owner;
    Menu[] menus;

    this(Window parent, char[] name = "") {
      this.name = name;
      peer = gtk_menu_bar_new();
      GtkContainer* p = cast(GtkContainer*)parent.getPeerForAdd();
      gtk_container_add(p,peer);
      gtk_widget_show(peer);
      owner = parent;
      owner.menubar = this;
    }
  }
  
  class Menu {
    MenuPeer peer;
    char[] name;
    MenuBar parentBar;
    GtkWidget* trigger;

    this(inout MenuBar bar, char[] label, char[] name = "") {
      this.name = name;
      parentBar = bar;
      char* cname = toStringz(label);
      peer = gtk_menu_new();
      trigger = gtk_menu_item_new_with_label(cname);
      gtk_menu_item_set_submenu(cast(GtkMenuItem*)trigger,peer);
      gtk_menu_shell_append(cast(GtkMenuShell*)bar.peer,trigger);
      gtk_widget_show(trigger);
      bar.menus ~= this;
    }

    void addSeparator() {
      GtkWidget* item = gtk_separator_menu_item_new();
      gtk_menu_shell_append(cast(GtkMenuShell*)peer,item);
      gtk_widget_show(item);
    }

    void add(char[] name, int cmd) {
      char* cname = toStringz(name);
      GtkWidget* item = gtk_menu_item_new_with_label(cname);
      gtk_menu_shell_append(cast(GtkMenuShell*)peer,item);
      g_object_set_data(cast(GObject*)item,"MinWinItemCommand",
			cast(gpointer)cmd);
      g_signal_connect_data(item,"activate",
			    cast(GCallback)&mw_menuitem_callback,
			    cast(gpointer)parentBar.owner,
			    null,cast(GConnectFlags)0);
      gtk_widget_show(item);
    }
  }
  extern (C)
    void mw_menuitem_callback(GtkWidget* w, gpointer ud) {
    Window x = cast(Window)ud;
    if (x) {
      int cmd = cast(int)g_object_get_data(cast(GObject*)w,"MinWinItemCommand");
      x.doCommand(cmd);
    }
  }
}
