/* Xt/Motif interface
 *
 * Written by Ben Hinkle.
 * Email comments and bug reports to ben.hinkle@gmail.com
 *
 * Since portions of this file (the lists of constants) are copied from
 * the C header files and edited to be in D syntax I am including the
 * copyright notices and license instructions present in those
 * files. The "software" referred to in the notices refers only to
 * this file motif.d and to no other part of MinWin or any library or
 * application created with MinWin. I'm not sure why such a notice
 * appears in a header file but it does so I'm reproducing it here.
 */

/***********************************************************
Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts,

			All Rights Reserved

Permission to use, copy, modify, and distribute this software and its 
documentation for any purpose and without fee is hereby granted, 
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in 
supporting documentation, and that the name Digital not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.  

DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.

******************************************************************/

/*

Copyright 1987, 1988, 1994, 1998  The Open Group

Permission to use, copy, modify, distribute, and sell this software and its
documentation for any purpose is hereby granted without fee, provided that
the above copyright notice appear in all copies and that both that
copyright notice and this permission notice appear in supporting
documentation.

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of The Open Group shall not be
used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from The Open Group.

*/

module minwin.motif;

import minwin.x11;
import minwin.motif_aux;

extern (C):

alias void* XtAppContext;
alias void* Widget;
alias void* WidgetClass;
alias char* String;
alias void* XtPointer;

alias char* XtString;
alias void* XmString;
alias char* XmStringCharSet;
alias char* XmStringTag;
alias char  XmStringComponentType;
alias ubyte Boolean;

alias uint XtIntervalId;

alias uint XtGeometryMask;
alias uint Cardinal;
alias ushort Dimension;
alias short Position;

alias Arg* ArgList;
alias void* XtArgVal;

struct Arg {
  String name;
  XtArgVal value;
}


void XtSetArg(inout Arg arg, String name, XtArgVal val) {
  arg.name = name;
  arg.value = val;
}

void XtToolkitInitialize();
XtAppContext XtCreateApplicationContext();
void XtAppMainLoop(XtAppContext context);
void XtAppNextEvent(XtAppContext context,XEvent* event);
Boolean XtAppPeekEvent(XtAppContext context,XEvent* event);
void XtDispatchEvent(XEvent* event);
void XtAppSetExitFlag(XtAppContext context);
Boolean XtAppGetExitFlag(XtAppContext context);
Display* XtOpenDisplay(XtAppContext app,char* disp, char* app_name,
		       char* app_cls, void* opts, int n_opts,
		       int*argc, char** argv);
Widget XtAppCreateShell(char* name, char* cls, WidgetClass wcls,
			Display* disp, void* args, int n);
// it looks like the D ... isn't compatible with C's ...
//  Widget XtVaAppCreateShell(char* name, char* cls, WidgetClass wcls,
//			  Display* disp, ...);
void XtRealizeWidget(Widget w);
void XtDestroyWidget(Widget w);
void XtSetSensitive(Widget w, Boolean b);
void XtSetKeyboardFocus(Widget root, Widget w);

Window XtWindow(Widget w);
Display* XtDisplay(Widget w);
Screen* XtScreen(Widget w);
void XtManageChild(Widget w);
void XtUnmanageChild(Widget w);
void XtConfigureWidget(Widget w,int x,int y, int w,int h, int edge);
Widget XtNameToWidget(Widget ref, XtString names);

alias void function(XtPointer closure,XtIntervalId* id) XtTimerCallbackProc;

XtIntervalId XtAppAddTimeOut(XtAppContext app,
    uint interval, XtTimerCallbackProc proc, XtPointer closure);

void XtRemoveTimeOut(XtIntervalId timer);


struct XtWidgetGeometry {
  XtGeometryMask request_mode;
  Position x, y;
  Dimension width, height, border_width;
  Widget sibling;
  int stack_mode;
};
enum {
    XtGeometryYes,
    XtGeometryNo,
    XtGeometryAlmost,
    XtGeometryDone
}
alias int XtGeometryResult;

enum {XtGrabNone, XtGrabNonexclusive, XtGrabExclusive}
alias int XtGrabKind;

XtGeometryResult XtQueryGeometry(Widget w,XtWidgetGeometry* intended,
				 XtWidgetGeometry* preferred);

// needed to access the C data in the Xt library
WidgetClass getTopLevelShellWidgetClass();

const int XtAllEvents  = -1;
const int XtIMXEvent=		1;
const int XtIMTimer=		2;
const int XtIMAlternateInput=	4;
const int XtIMSignal=		8;
const int XtIMAll = (XtIMXEvent | XtIMTimer | XtIMAlternateInput | XtIMSignal);
alias uint XtInputMask;
void XtAppProcessEvent(XtAppContext context,XtInputMask mask);

alias void function(Widget w, XtPointer appdata, 
		    XEvent* event, int* cont) XtEventHandler;
alias void function(Widget w, XtPointer appdata, 
		    XEvent* event) XtCallbackProc;
struct XtCallbackRec {
    XtCallbackProc  callback;
    XtPointer	    closure;
};
alias XtCallbackRec* XtCallbackList;

enum {XtCallbackNoList,	XtCallbackHasNone,XtCallbackHasSome }
alias int XtCallbackStatus;

void XtAddEventHandler(Widget w, EventMask mask,int nonmask,
		       XtEventHandler proc, XtPointer data);
void XtAddCallback(Widget w, char* name, 
		   XtCallbackProc proc, XtPointer data);
Atom XInternAtom(Display* disp, char* name, int ifexists);
void XmAddProtocolCallback(Widget shell, Atom prop, 
			   Atom proto_atom, XtCallbackProc callback,
			   XtPointer data);

XmString XmStringCreate(char *text,XmStringCharSet charset);
XmString XmStringCreateSimple(char *text);
XmString XmStringCreateLocalized(String text);
void XmStringFree(XmString str);
XtPointer XmStringUnparse(XmString string,
			  XmStringTag tag,
			  XmTextType tag_type,
			  XmTextType output_type,
			  XmParseTable parse_table,
			  Cardinal parse_count,
			  XmParseModel parse_model);

void XtGetValues(Widget w, ArgList args, int n);
void XtSetValues(Widget w, ArgList args, int n);
enum{ XmALIGNMENT_BEGINNING, XmALIGNMENT_CENTER,
	XmALIGNMENT_END,XmALIGNMENT_UNSPECIFIED}
enum{ XmALIGNMENT_BASELINE_TOP,    /* XmALIGNMENT_CENTER, */
	XmALIGNMENT_BASELINE_BOTTOM = 2, XmALIGNMENT_WIDGET_TOP,
	XmALIGNMENT_WIDGET_BOTTOM }

enum { XmDESTROY, XmUNMAP, XmDO_NOTHING }

struct XmPushButtonCallbackStruct {
  int reason;
  XEvent* event;
  int click_count;
};

Widget XmCreatePushButton(Widget par,char* name, ArgList args, int n);
Widget XmCreateLabel(Widget par,char* name, ArgList args, int n);
Widget XmCreateDrawingArea(Widget par,char* name, ArgList args, int n);
Widget XmCreateBulletinBoard(Widget par,char* name, ArgList args, int n);
Widget XmCreateForm(Widget par,char* name, ArgList args, int n);
Widget XmCreateDialogShell(Widget par,char* name, ArgList args, int n);
Widget XmCreateScrollBar(Widget par,char* name, ArgList args, int n);
Widget XmCreateScrolledWindow(Widget par,char* name, ArgList args, int n);
Widget XmCreateTabStack(Widget par,char* name, ArgList args, int n);

enum{ XmNO_ORIENTATION, XmVERTICAL, XmHORIZONTAL }
enum{ XmVARIABLE, XmCONSTANT, XmRESIZE_IF_POSSIBLE }
enum{ XmAUTOMATIC, XmAPPLICATION_DEFINED}
enum{ /* XmSTATIC */ XmAS_NEEDED = 1}

Widget XmCreateDropDownComboBox(Widget par,char* name, ArgList args, int n);
Widget XmCreateDropDownList(Widget par,char* name, ArgList args, int n);
Widget XmCreateList(Widget par,char* name, ArgList args, int n);
void XmComboBoxAddItem (Widget w, XmString item,int pos, Boolean unique);
void XmComboBoxSelectItem (Widget w,XmString item);

void XmTextSetString(Widget w,char*str);
char* XmTextGetString(Widget w);

struct XmToggleButtonCallbackStruct {
  int reason;
  XEvent* event;
  int set;
};
Widget XmCreateToggleButtonGadget(Widget par,char* name, ArgList args, int n);
Widget XmCreateToggleButton(Widget par,char* name, ArgList args, int n);
Boolean XmToggleButtonGetState(Widget w);
void XmToggleButtonSetState(Widget w,Boolean newstate,Boolean notify) ;
Boolean XmToggleButtonSetValue(Widget w,ubyte newstate,Boolean notify );

Widget XmCreateSimpleRadioBox(Widget par,char* name, ArgList args, int n);
Widget XmCreateSimpleCheckBox(Widget par,char* name, ArgList args, int n);

enum{
 XmN_OF_MANY = 1, XmONE_OF_MANY=2, XmONE_OF_MANY_ROUND=3, XmONE_OF_MANY_DIAMOND=4
   }
enum{	XmDIALOG_NONE,			XmDIALOG_APPLY_BUTTON,
	XmDIALOG_CANCEL_BUTTON,		XmDIALOG_DEFAULT_BUTTON,
	XmDIALOG_OK_BUTTON,		XmDIALOG_FILTER_LABEL,
	XmDIALOG_FILTER_TEXT,		XmDIALOG_HELP_BUTTON,
	XmDIALOG_LIST,			XmDIALOG_LIST_LABEL,
	XmDIALOG_MESSAGE_LABEL,		XmDIALOG_SELECTION_LABEL,
	XmDIALOG_SYMBOL_LABEL,		XmDIALOG_TEXT,
	XmDIALOG_SEPARATOR,		XmDIALOG_DIR_LIST,
	XmDIALOG_DIR_LIST_LABEL
	}
enum{	XmDIALOG_MODELESS,		XmDIALOG_PRIMARY_APPLICATION_MODAL,
	XmDIALOG_FULL_APPLICATION_MODAL,XmDIALOG_SYSTEM_MODAL
	}
enum{	XmDIALOG_TEMPLATE,		XmDIALOG_ERROR,
	XmDIALOG_INFORMATION,		XmDIALOG_MESSAGE,
	XmDIALOG_QUESTION,		XmDIALOG_WARNING,
	XmDIALOG_WORKING
	}
enum {
    XmOUTPUT_ALL,			XmOUTPUT_BETWEEN,
    XmOUTPUT_BEGINNING,			XmOUTPUT_END,
    XmOUTPUT_BOTH
}
alias int XmParseModel;
enum {
    XmCHARSET_TEXT,			XmMULTIBYTE_TEXT,
    XmWIDECHAR_TEXT,                    XmNO_TEXT
}
alias int XmTextType;

alias void* XmParseMapping;
alias XmParseMapping *XmParseTable;

Widget XmCreateMessageDialog(Widget par,char* name, ArgList args, int n);
Widget XmCreateInformationDialog(Widget par,char* name, ArgList args, int n);
Widget XmCreateWarningDialog(Widget par,char* name, ArgList args, int n);
Widget XmCreateErrorDialog(Widget par,char* name, ArgList args, int n);
Widget XmCreateQuestionDialog(Widget par,char* name, ArgList args, int n);
Widget XmCreateFileSelectionDialog(Widget par,char* name, ArgList args, int n);
struct XmFileSelectionBoxCallbackStruct {
    int 	reason;
    XEvent	*event;
    XmString	value;
    int		length;
    XmString	mask;
    int		mask_length;
    XmString	dir;
    int		dir_length;
    XmString    pattern;
    int		pattern_length;
};

Widget XmCreateMenuBar(Widget par,char* name, ArgList args, int n);
Widget XmCreatePulldownMenu(Widget par,char* name, ArgList args, int n);
Widget XmCreateSeparator(Widget par,char* name, ArgList args, int n);
Widget XmCreateCascadeButton(Widget par,char* name, ArgList args, int n);
Widget XmCreateText(Widget par,char* name, ArgList args, int n);
Widget XmCreateFrame(Widget par,char* name, ArgList args, int n);

void XtFree(void* ptr);

enum{	XmATTACH_NONE,			XmATTACH_FORM,
	XmATTACH_OPPOSITE_FORM,		XmATTACH_WIDGET,
	XmATTACH_OPPOSITE_WIDGET,	XmATTACH_POSITION,
	XmATTACH_SELF
	}
enum{	XmRESIZE_NONE,			XmRESIZE_GROW,
	XmRESIZE_ANY
	}

enum{	XmMULTI_LINE_EDIT,		XmSINGLE_LINE_EDIT
	}
enum{	XmFRAME_GENERIC_CHILD,          XmFRAME_WORKAREA_CHILD,
        XmFRAME_TITLE_CHILD
	}

const char[] XtNtitle = "title";
const char[] XmNtitle = XtNtitle;

const char[] XmSTRING_DEFAULT_CHARSET	= XmS;
const char[] XmSTRING_ISO8859_1	       = "ISO8859-1";

const char[] XtNaccelerators = "accelerators";
const char[] XtNallowHoriz = "allowHoriz";
const char[] XtNallowVert = "allowVert";
const char[] XtNancestorSensitive = "ancestorSensitive";
const char[] XtNbackground = "background";
const char[] XtNbackgroundPixmap = "backgroundPixmap";
const char[] XtNbitmap = "bitmap";
const char[] XtNborderColor = "borderColor";
const char[] XtNborder = "borderColor";
const char[] XtNborderPixmap = "borderPixmap";
const char[] XtNborderWidth = "borderWidth";
const char[] XtNcallback = "callback";
const char[] XtNchildren = "children";
const char[] XtNcolormap = "colormap";
const char[] XtNdepth = "depth";
const char[] XtNdestroyCallback = "destroyCallback";
const char[] XtNeditType = "editType";
const char[] XtNfile = "file";
const char[] XtNfont = "font";
const char[] XtNforceBars = "forceBars";
const char[] XtNforeground = "foreground";
const char[] XtNfunction = "function";
const char[] XtNheight = "height";
const char[] XtNhighlight = "highlight";
const char[] XtNhSpace = "hSpace";
const char[] XtNindex = "index";
const char[] XtNinitialResourcesPersistent = "initialResourcesPersistent";
const char[] XtNinnerHeight = "innerHeight";
const char[] XtNinnerWidth = "innerWidth";
const char[] XtNinnerWindow = "innerWindow";
const char[] XtNinsertPosition = "insertPosition";
const char[] XtNinternalHeight = "internalHeight";
const char[] XtNinternalWidth = "internalWidth";
const char[] XtNjumpProc = "jumpProc";
const char[] XtNjustify = "justify";
const char[] XtNknobHeight = "knobHeight";
const char[] XtNknobIndent = "knobIndent";
const char[] XtNknobPixel = "knobPixel";
const char[] XtNknobWidth = "knobWidth";
const char[] XtNlabel = "label";
const char[] XtNlength = "length";
const char[] XtNlowerRight = "lowerRight";
const char[] XtNmappedWhenManaged = "mappedWhenManaged";
const char[] XtNmenuEntry = "menuEntry";
const char[] XtNname = "name";
const char[] XtNnotify = "notify";
const char[] XtNnumChildren = "numChildren";
const char[] XtNorientation = "orientation";
const char[] XtNparameter = "parameter";
const char[] XtNpixmap = "pixmap";
const char[] XtNpopupCallback = "popupCallback";
const char[] XtNpopdownCallback = "popdownCallback";
const char[] XtNresize = "resize";
const char[] XtNreverseVideo = "reverseVideo";
const char[] XtNscreen = "screen";
const char[] XtNscrollProc = "scrollProc";
const char[] XtNscrollDCursor = "scrollDCursor";
const char[] XtNscrollHCursor = "scrollHCursor";
const char[] XtNscrollLCursor = "scrollLCursor";
const char[] XtNscrollRCursor = "scrollRCursor";
const char[] XtNscrollUCursor = "scrollUCursor";
const char[] XtNscrollVCursor = "scrollVCursor";
const char[] XtNselection = "selection";
const char[] XtNselectionArray = "selectionArray";
const char[] XtNsensitive = "sensitive";
const char[] XtNshown = "shown";
const char[] XtNspace = "space";
const char[] XtNstring = "string";
const char[] XtNtextOptions = "textOptions";
const char[] XtNtextSink = "textSink";
const char[] XtNtextSource = "textSource";
const char[] XtNthickness = "thickness";
const char[] XtNthumb = "thumb";
const char[] XtNthumbProc = "thumbProc";
const char[] XtNtop = "top";
const char[] XtNtranslations = "translations";
const char[] XtNunrealizeCallback = "unrealizeCallback";
const char[] XtNupdate = "update";
const char[] XtNuseBottom = "useBottom";
const char[] XtNuseRight = "useRight";
const char[] XtNvalue = "value";
const char[] XtNvSpace = "vSpace";
const char[] XtNwidth = "width";
const char[] XtNwindow = "window";
const char[] XtNx = "x";
const char[] XtNy = "y";

const char[] XtCAccelerators = "Accelerators";
const char[] XtCBackground = "Background";
const char[] XtCBitmap = "Bitmap";
const char[] XtCBoolean = "Boolean";
const char[] XtCBorderColor = "BorderColor";
const char[] XtCBorderWidth = "BorderWidth";
const char[] XtCCallback = "Callback";
const char[] XtCColormap = "Colormap";
const char[] XtCColor = "Color";
const char[] XtCCursor = "Cursor";
const char[] XtCDepth = "Depth";
const char[] XtCEditType = "EditType";
const char[] XtCEventBindings = "EventBindings";
const char[] XtCFile = "File";
const char[] XtCFont = "Font";
const char[] XtCForeground = "Foreground";
const char[] XtCFraction = "Fraction";
const char[] XtCFunction = "Function";
const char[] XtCHeight = "Height";
const char[] XtCHSpace = "HSpace";
const char[] XtCIndex = "Index";
const char[] XtCInitialResourcesPersistent = "InitialResourcesPersistent";
const char[] XtCInsertPosition = "InsertPosition";
const char[] XtCInterval = "Interval";
const char[] XtCJustify = "Justify";
const char[] XtCKnobIndent = "KnobIndent";
const char[] XtCKnobPixel = "KnobPixel";
const char[] XtCLabel = "Label";
const char[] XtCLength = "Length";
const char[] XtCMappedWhenManaged = "MappedWhenManaged";
const char[] XtCMargin = "Margin";
const char[] XtCMenuEntry = "MenuEntry";
const char[] XtCNotify = "Notify";
const char[] XtCOrientation = "Orientation";
const char[] XtCParameter = "Parameter";
const char[] XtCPixmap = "Pixmap";
const char[] XtCPosition = "Position";
const char[] XtCReadOnly = "ReadOnly";
const char[] XtCResize = "Resize";
const char[] XtCReverseVideo = "ReverseVideo";
const char[] XtCScreen = "Screen";
const char[] XtCScrollProc = "ScrollProc";
const char[] XtCScrollDCursor = "ScrollDCursor";
const char[] XtCScrollHCursor = "ScrollHCursor";
const char[] XtCScrollLCursor = "ScrollLCursor";
const char[] XtCScrollRCursor = "ScrollRCursor";
const char[] XtCScrollUCursor = "ScrollUCursor";
const char[] XtCScrollVCursor = "ScrollVCursor";
const char[] XtCSelection = "Selection";
const char[] XtCSensitive = "Sensitive";
const char[] XtCSelectionArray = "SelectionArray";
const char[] XtCSpace = "Space";
const char[] XtCString = "String";
const char[] XtCTextOptions = "TextOptions";
const char[] XtCTextPosition = "TextPosition";
const char[] XtCTextSink = "TextSink";
const char[] XtCTextSource = "TextSource";
const char[] XtCThickness = "Thickness";
const char[] XtCThumb = "Thumb";
const char[] XtCTranslations = "Translations";
const char[] XtCValue = "Value";
const char[] XtCVSpace = "VSpace";
const char[] XtCWidth = "Width";
const char[] XtCWindow = "Window";
const char[] XtCX = "X";
const char[] XtCY = "Y";
const char[] XtRAcceleratorTable = "AcceleratorTable";

const char[] XmS = "";
const char[] XmCAccelerator = "Accelerator";
const char[] XmCAcceleratorText = "AcceleratorText";
const char[] XmCAdjustLast = "AdjustLast";
const char[] XmCAdjustMargin = "AdjustMargin";
const char[] XmCAlignment = "Alignment";
const char[] XmCAllowOverlap = "AllowOverlap";
const char[] XmCAllowUnusedSpace = "AllowUnusedSpace";
const char[] XmCAnimationMask = "AnimationMask";
const char[] XmCAnimationPixmap = "AnimationPixmap";
const char[] XmCAnimationPixmapDepth = "AnimationPixmapDepth";
const char[] XmCAnimationStyle = "AnimationStyle";
const char[] XmCApplyLabelString = "ApplyLabelString";
const char[] XmCArmCallback = "ArmCallback";
const char[] XmCArmColor = "ArmColor";
const char[] XmCArmPixmap = "ArmPixmap";
const char[] XmCArrowDirection = "ArrowDirection";
const char[] XmCAttachment = "Attachment";
const char[] XmCAudibleWarning = "AudibleWarning";
const char[] XmCAutoShowCursorPosition = "AutoShowCursorPosition";
const char[] XmCAutoUnmanage = "AutoUnmanage";
const char[] XmCAutomaticSelection = "AutomaticSelection";
const char[] XmCAvailability = "Availability";
const char[] XmCBackgroundPixmap = "BackgroundPixmap";
const char[] XmCBlendModel = "BlendModel";
const char[] XmCBlinkRate = "BlinkRate";
const char[] XmCBottomShadowColor = "BottomShadowColor";
const char[] XmCBottomShadowPixmap = "BottomShadowPixmap";
const char[] XmCButtonAcceleratorText = "ButtonAcceleratorText";
const char[] XmCButtonAccelerators = "ButtonAccelerators";
const char[] XmCButtonCount = "ButtonCount";
const char[] XmCButtonFontList = "ButtonFontList";
const char[] XmCButtonMnemonicCharSets = "ButtonMnemonicCharSets";
const char[] XmCButtonMnemonics = "ButtonMnemonics";
const char[] XmCButtonSet = "ButtonSet";
const char[] XmCButtonType = "ButtonType";
const char[] XmCButtons = "Buttons";
const char[] XmCCancelLabelString = "CancelLabelString";
const char[] XmCChildHorizontalAlignment = "ChildHorizontalAlignment";
const char[] XmCChildHorizontalSpacing = "ChildHorizontalSpacing";
const char[] XmCChildPlacement = "ChildPlacement";
const char[] XmCChildType = "ChildType";
const char[] XmCChildVerticalAlignment = "ChildVerticalAlignment";
const char[] XmCChildren = "Children";
const char[] XmCClientData = "ClientData";
const char[] XmCClipWindow = "ClipWindow";
const char[] XmCColumns = "Columns";
const char[] XmCCommandWindow = "CommandWindow";
const char[] XmCCommandWindowLocation = "CommandWindowLocation";
const char[] XmCConvertProc = "ConvertProc";
const char[] XmCCursorBackground = "CursorBackground";
const char[] XmCCursorForeground = "CursorForeground";
const char[] XmCCursorPosition = "CursorPosition";
const char[] XmCCursorPositionVisible = "CursorPositionVisible";
const char[] XmCDarkThreshold = "DarkThreshold";
const char[] XmCDecimalPoints = "DecimalPoints";
const char[] XmCDefaultButtonShadowThickness = "DefaultButtonShadowThickness";
const char[] XmCDefaultButtonType = "DefaultButtonType";
const char[] XmCDefaultCopyCursorIcon = "DefaultCopyCursorIcon";
const char[] XmCDefaultFontList = "DefaultFontList";
const char[] XmCDefaultInvalidCursorIcon = "DefaultInvalidCursorIcon";
const char[] XmCDefaultLinkCursorIcon = "DefaultLinkCursorIcon";
const char[] XmCDefaultMoveCursorIcon = "DefaultMoveCursorIcon";
const char[] XmCDefaultNoneCursorIcon = "DefaultNoneCursorIcon";
const char[] XmCDefaultPosition = "DefaultPosition";
const char[] XmCDefaultSourceCursorIcon = "DefaultSourceCursorIcon";
const char[] XmCDefaultValidCursorIcon = "DefaultValidCursorIcon";
const char[] XmCDeleteResponse = "DeleteResponse";
const char[] XmCDesktopParent = "DesktopParent";
const char[] XmCDialogStyle = "DialogStyle";
const char[] XmCDialogTitle = "DialogTitle";
const char[] XmCDialogType = "DialogType";
const char[] XmCDirListItemCount = "DirListItemCount";
const char[] XmCDirListItems = "DirListItems";
const char[] XmCDirListLabelString = "DirListLabelString";
const char[] XmCDirMask = "DirMask";
const char[] XmCDirSearchProc = "DirSearchProc";
const char[] XmCDirSpec = "DirSpec";
const char[] XmCDirectory = "Directory";
const char[] XmCDirectoryValid = "DirectoryValid";
const char[] XmCDisarmCallback = "DisarmCallback";
const char[] XmCDoubleClickInterval = "DoubleClickInterval";
const char[] XmCDragContextClass = "DragContextClass";
const char[] XmCDragDropFinishCallback = "DragDropFinishCallback";
const char[] XmCDragIconClass = "DragIconClass";
const char[] XmCDragInitiatorProtocolStyle = "DragInitiatorProtocolStyle";
const char[] XmCDragMotionCallback = "DragMotionCallback";
const char[] XmCDragOperations = "DragOperations";
const char[] XmCDragOverMode = "DragOverMode";
const char[] XmCDragProc = "DragProc";
const char[] XmCDragReceiverProtocolStyle = "DragReceiverProtocolStyle";
const char[] XmCDropProc = "DropProc";
const char[] XmCDropRectangles = "DropRectangles";
const char[] XmCDropSiteActivity = "DropSiteActivity";
const char[] XmCDropSiteEnterCallback = "DropSiteEnterCallback";
const char[] XmCDropSiteLeaveCallback = "DropSiteLeaveCallback";
const char[] XmCDropSiteManagerClass = "DropSiteManagerClass";
const char[] XmCDropSiteOperations = "DropSiteOperations";
const char[] XmCDropSiteType = "DropSiteType";
const char[] XmCDropStartCallback = "DropStartCallback";
const char[] XmCDropTransferClass = "DropTransferClass";
const char[] XmCDropTransfers = "DropTransfers";
const char[] XmCEditable = "Editable";
const char[] XmCEntryBorder = "EntryBorder";
const char[] XmCEntryClass = "EntryClass";
const char[] XmCExportTargets = "ExportTargets";
const char[] XmCExposeCallback = "ExposeCallback";
const char[] XmCExtensionType = "ExtensionType";
const char[] XmCFileListItemCount = "FileListItemCount";
const char[] XmCFileListItems = "FileListItems";
const char[] XmCFileListLabelString = "FileListLabelString";
const char[] XmCFileSearchProc = "FileSearchProc";
const char[] XmCFileTypeMask = "FileTypeMask";
const char[] XmCFillOnArm = "FillOnArm";
const char[] XmCFillOnSelect = "FillOnSelect";
const char[] XmCFilterLabelString = "FilterLabelString";
const char[] XmCFontList = "FontList";
const char[] XmCForegroundThreshold = "ForegroundThreshold";
const char[] XmCHelpLabelString = "HelpLabelString";
const char[] XmCHighlightColor = "HighlightColor";
const char[] XmCHighlightOnEnter = "HighlightOnEnter";
const char[] XmCHighlightPixmap = "HighlightPixmap";
const char[] XmCHighlightThickness = "HighlightThickness";
const char[] XmCHorizontalFontUnit = "HorizontalFontUnit";
const char[] XmCHorizontalScrollBar = "HorizontalScrollBar";
const char[] XmCHot = "Hot";
const char[] XmCICCHandle = "ICCHandle";
const char[] XmCImportTargets = "ImportTargets";
const char[] XmCIncrement = "Increment";
const char[] XmCIncremental = "Incremental";
const char[] XmCIndicatorOn = "IndicatorOn";
const char[] XmCIndicatorSize = "IndicatorSize";
const char[] XmCIndicatorType = "IndicatorType";
const char[] XmCInitialDelay = "InitialDelay";
const char[] XmCInitialFocus = "InitialFocus";
const char[] XmCInputCreate = "InputCreate";
const char[] XmCInputMethod = "InputMethod";
const char[] XmCInvalidCursorForeground = "InvalidCursorForeground";
const char[] XmCIsAligned = "IsAligned";
const char[] XmCIsHomogeneous = "IsHomogeneous";
const char[] XmCItemCount = "ItemCount";
const char[] XmCItems = "Items";
const char[] XmCKeyboardFocusPolicy = "KeyboardFocusPolicy";
const char[] XmCLabelFontList = "LabelFontList";
const char[] XmCLabelInsensitivePixmap = "LabelInsensitivePixmap";
const char[] XmCLabelPixmap = "LabelPixmap";
const char[] XmCLabelString = "LabelString";
const char[] XmCLabelType = "LabelType";
const char[] XmCLightThreshold = "LightThreshold";
const char[] XmCListLabelString = "ListLabelString";
const char[] XmCListMarginHeight = "ListMarginHeight";
const char[] XmCListMarginWidth = "ListMarginWidth";
const char[] XmCListSizePolicy = "ListSizePolicy";
const char[] XmCListSpacing = "ListSpacing";
const char[] XmCListUpdated = "ListUpdated";
const char[] XmCLogicalParent = "LogicalParent";
const char[] XmCMainWindowMarginHeight = "MainWindowMarginHeight";
const char[] XmCMainWindowMarginWidth = "MainWindowMarginWidth";
const char[] XmCMappingDelay = "MappingDelay";
const char[] XmCMarginBottom = "MarginBottom";
const char[] XmCMarginHeight = "MarginHeight";
const char[] XmCMarginLeft = "MarginLeft";
const char[] XmCMarginRight = "MarginRight";
const char[] XmCMarginTop = "MarginTop";
const char[] XmCMarginWidth = "MarginWidth";
const char[] XmCMask = "Mask";
const char[] XmCMaxItems = "MaxItems";
const char[] XmCMaxLength = "MaxLength";
const char[] XmCMaxValue = "MaxValue";
const char[] XmCMaximum = "Maximum";
const char[] XmCMenuBar = "MenuBar";
const char[] XmCMenuPost = "MenuPost";
const char[] XmCMenuWidget = "MenuWidget";
const char[] XmCMessageProc = "MessageProc";
const char[] XmCMessageWindow = "MessageWindow";
const char[] XmCMinimizeButtons = "MinimizeButtons";
const char[] XmCMinimum = "Minimum";
const char[] XmCMnemonic = "Mnemonic";
const char[] XmCMnemonicCharSet = "MnemonicCharSet";
const char[] XmCMoveOpaque = "MoveOpaque";
const char[] XmCMultiClick = "MultiClick";
const char[] XmCMustMatch = "MustMatch";
const char[] XmCMwmDecorations = "MwmDecorations";
const char[] XmCMwmFunctions = "MwmFunctions";
const char[] XmCMwmInputMode = "MwmInputMode";
const char[] XmCMwmMenu = "MwmMenu";
const char[] XmCMwmMessages = "MwmMessages";
const char[] XmCNavigationType = "NavigationType";
const char[] XmCNeedsMotion = "NeedsMotion";
const char[] XmCNoMatchString = "NoMatchString";
const char[] XmCNoResize = "NoResize";
const char[] XmCNoneCursorForeground = "NoneCursorForeground";
const char[] XmCNotifyProc = "NotifyProc";
const char[] XmCNumChildren = "NumChildren";
const char[] XmCNumColumns = "NumColumns";
const char[] XmCNumDropRectangles = "NumDropRectangles";
const char[] XmCNumDropTransfers = "NumDropTransfers";
const char[] XmCNumExportTargets = "NumExportTargets";
const char[] XmCNumImportTargets = "NumImportTargets";
const char[] XmCOffset = "Offset";
const char[] XmCOkLabelString = "OkLabelString";
const char[] XmCOperationChangedCallback = "OperationChangedCallback";
const char[] XmCOperationCursorIcon = "OperationCursorIcon";
const char[] XmCOptionLabel = "OptionLabel";
const char[] XmCOptionMnemonic = "OptionMnemonic";
const char[] XmCOutputCreate = "OutputCreate";
const char[] XmCPacking = "Packing";
const char[] XmCPageIncrement = "PageIncrement";
const char[] XmCPaneMaximum = "PaneMaximum";
const char[] XmCPaneMinimum = "PaneMinimum";
const char[] XmCPattern = "Pattern";
const char[] XmCPendingDelete = "PendingDelete";
const char[] XmCPopupEnabled = "PopupEnabled";
const char[] XmCPositionIndex = "PositionIndex";
const char[] XmCPostFromButton = "PostFromButton";
const char[] XmCPostFromCount = "PostFromCount";
const char[] XmCPostFromList = "PostFromList";
const char[] XmCPreeditType = "PreeditType";
const char[] XmCProcessingDirection = "ProcessingDirection";
const char[] XmCPromptString = "PromptString";
const char[] XmCProtocolCallback = "ProtocolCallback";
const char[] XmCPushButtonEnabled = "PushButtonEnabled";
const char[] XmCQualifySearchDataProc = "QualifySearchDataProc";
const char[] XmCRadioAlwaysOne = "RadioAlwaysOne";
const char[] XmCRadioBehavior = "RadioBehavior";
const char[] XmCRecomputeSize = "RecomputeSize";
const char[] XmCRectangles = "Rectangles";
const char[] XmCRepeatDelay = "RepeatDelay";
const char[] XmCResizeCallback = "ResizeCallback";
const char[] XmCResizeHeight = "ResizeHeight";
const char[] XmCResizePolicy = "ResizePolicy";
const char[] XmCResizeWidth = "ResizeWidth";
const char[] XmCRowColumnType = "RowColumnType";
const char[] XmCRows = "Rows";
const char[] XmCRubberPositioning = "RubberPositioning";
const char[] XmCSashHeight = "SashHeight";
const char[] XmCSashIndent = "SashIndent";
const char[] XmCSashWidth = "SashWidth";
const char[] XmCScaleHeight = "ScaleHeight";
const char[] XmCScaleMultiple = "ScaleMultiple";
const char[] XmCScaleWidth = "ScaleWidth";
const char[] XmCScroll = "Scroll";
const char[] XmCScrollBarDisplayPolicy = "ScrollBarDisplayPolicy";
const char[] XmCScrollBarPlacement = "ScrollBarPlacement";
const char[] XmCScrollSide = "ScrollSide";
const char[] XmCScrolledWindowMarginHeight = "ScrolledWindowMarginHeight";
const char[] XmCScrolledWindowMarginWidth = "ScrolledWindowMarginWidth";
const char[] XmCScrollingPolicy = "ScrollingPolicy";
const char[] XmCSelectColor = "SelectColor";
const char[] XmCSelectInsensitivePixmap = "SelectInsensitivePixmap";
const char[] XmCSelectPixmap = "SelectPixmap";
const char[] XmCSelectThreshold = "SelectThreshold";
const char[] XmCSelectedItemCount = "SelectedItemCount";
const char[] XmCSelectedItems = "SelectedItems";
const char[] XmCSelectionArrayCount = "SelectionArrayCount";
const char[] XmCSelectionLabelString = "SelectionLabelString";
const char[] XmCSelectionPolicy = "SelectionPolicy";
const char[] XmCSeparatorOn = "SeparatorOn";
const char[] XmCSeparatorType = "SeparatorType";
const char[] XmCSet = "Set";
const char[] XmCShadowThickness = "ShadowThickness";
const char[] XmCShadowType = "ShadowType";
const char[] XmCShellUnitType = "ShellUnitType";
const char[] XmCShowArrows = "ShowArrows";
const char[] XmCShowAsDefault = "ShowAsDefault";
const char[] XmCShowSeparator = "ShowSeparator";
const char[] XmCShowValue = "ShowValue";
const char[] XmCSimpleCheckBox = "SimpleCheckBox";
const char[] XmCSimpleMenuBar = "SimpleMenuBar";
const char[] XmCSimpleOptionMenu = "SimpleOptionMenu";
const char[] XmCSimplePopupMenu = "SimplePopupMenu";
const char[] XmCSimplePulldownMenu = "SimplePulldownMenu";
const char[] XmCSimpleRadioBox = "SimpleRadioBox";
const char[] XmCSizePolicy = "SizePolicy";
const char[] XmCSliderSize = "SliderSize";
const char[] XmCSource = "Source";
const char[] XmCSourceCursorIcon = "SourceCursorIcon";
const char[] XmCSourceIsExternal = "SourceIsExternal";
const char[] XmCSourcePixmapIcon = "SourcePixmapIcon";
const char[] XmCSourceWidget = "SourceWidget";
const char[] XmCSourceWindow = "SourceWindow";
const char[] XmCSpacing = "Spacing";
const char[] XmCStartTime = "StartTime";
const char[] XmCStateCursorIcon = "StateCursorIcon";
const char[] XmCStringDirection = "StringDirection";
const char[] XmCTearOffModel = "TearOffModel";
const char[] XmCTextFontList = "TextFontList";
const char[] XmCTextString = "TextString";
const char[] XmCTextValue = "TextValue";
const char[] XmCTitleString = "TitleString";
const char[] XmCTopCharacter = "TopCharacter";
const char[] XmCTopItemPosition = "TopItemPosition";
const char[] XmCTopLevelEnterCallback = "TopLevelEnterCallback";
const char[] XmCTopLevelLeaveCallback = "TopLevelLeaveCallback";
const char[] XmCTopShadowColor = "TopShadowColor";
const char[] XmCTopShadowPixmap = "TopShadowPixmap";
const char[] XmCTransferProc = "TransferProc";
const char[] XmCTransferStatus = "TransferStatus";
const char[] XmCTraversalOn = "TraversalOn";
const char[] XmCTraversalType = "TraversalType";
const char[] XmCTreeUpdateProc = "TreeUpdateProc";
const char[] XmCTroughColor = "TroughColor";
const char[] XmCUnitType = "UnitType";
const char[] XmCUnpostBehavior = "UnpostBehavior";
const char[] XmCUnselectPixmap = "UnselectPixmap";
const char[] XmCUpdateSliderSize = "UpdateSliderSize";
const char[] XmCUseAsyncGeometry = "UseAsyncGeometry";
const char[] XmCUserData = "UserData";
const char[] XmCValidCursorForeground = "ValidCursorForeground";
const char[] XmCValueChangedCallback = "ValueChangedCallback";
const char[] XmCValueWcs = "ValueWcs";
const char[] XmCVerifyBell = "VerifyBell";
const char[] XmCVerticalAlignment = "VerticalAlignment";
const char[] XmCVerticalFontUnit = "VerticalFontUnit";
const char[] XmCVerticalScrollBar = "VerticalScrollBar";
const char[] XmCVisibleItemCount = "VisibleItemCount";
const char[] XmCVisibleWhenOff = "VisibleWhenOff";
const char[] XmCVisualPolicy = "VisualPolicy";
const char[] XmCWhichButton = "WhichButton";
const char[] XmCWordWrap = "WordWrap";
const char[] XmCWorkWindow = "WorkWindow";
const char[] XmCXmString = "XmString";
const char[] XmNaccelerator = "accelerator";
const char[] XmNacceleratorText = "acceleratorText";
const char[] XmNactivateCallback = "activateCallback";
const char[] XmNadjustLast = "adjustLast";
const char[] XmNadjustMargin = "adjustMargin";
const char[] XmNalignment = "alignment";
const char[] XmNallowOverlap = "allowOverlap";
const char[] XmNallowResize = "allowResize";
const char[] XmNallowUnusedSpace = "allowUnusedSpace";
const char[] XmNanimationMask = "animationMask";
const char[] XmNanimationPixmap = "animationPixmap";
const char[] XmNanimationPixmapDepth = "animationPixmapDepth";
const char[] XmNanimationStyle = "animationStyle";
const char[] XmNapplyCallback = "applyCallback";
const char[] XmNapplyLabelString = "applyLabelString";
const char[] XmNarmCallback = "armCallback";
const char[] XmNarmColor = "armColor";
const char[] XmNarmPixmap = "armPixmap";
const char[] XmNarrowDirection = "arrowDirection";
const char[] XmNattachment = "attachment";
const char[] XmNaudibleWarning = "audibleWarning";
const char[] XmNautoShowCursorPosition = "autoShowCursorPosition";
const char[] XmNautoUnmanage = "autoUnmanage";
const char[] XmNautomaticSelection = "automaticSelection";
const char[] XmNavailability = "availability";
const char[] XmNblendModel = "blendModel";
const char[] XmNblinkRate = "blinkRate";
const char[] XmNbottomAttachment = "bottomAttachment";
const char[] XmNbottomOffset = "bottomOffset";
const char[] XmNbottomPosition = "bottomPosition";
const char[] XmNbottomShadowColor = "bottomShadowColor";
const char[] XmNbottomShadowPixmap = "bottomShadowPixmap";
const char[] XmNbottomWidget = "bottomWidget";
const char[] XmNbrowseSelectionCallback = "browseSelectionCallback";
const char[] XmNbuttonAcceleratorText = "buttonAcceleratorText";
const char[] XmNbuttonAccelerators = "buttonAccelerators";
const char[] XmNbuttonCount = "buttonCount";
const char[] XmNbuttonFontList = "buttonFontList";
const char[] XmNbuttonMnemonicCharSets = "buttonMnemonicCharSets";
const char[] XmNbuttonMnemonics = "buttonMnemonics";
const char[] XmNbuttonSet = "buttonSet";
const char[] XmNbuttonType = "buttonType";
const char[] XmNbuttons = "buttons";
const char[] XmNcancelButton = "cancelButton";
const char[] XmNcancelCallback = "cancelCallback";
const char[] XmNcancelLabelString = "cancelLabelString";
const char[] XmNcascadePixmap = "cascadePixmap";
const char[] XmNcascadingCallback = "cascadingCallback";
const char[] XmNchildHorizontalAlignment = "childHorizontalAlignment";
const char[] XmNchildHorizontalSpacing = "childHorizontalSpacing";
const char[] XmNchildPlacement = "childPlacement";
const char[] XmNchildPosition = "childPosition";
const char[] XmNchildType = "childType";
const char[] XmNchildVerticalAlignment = "childVerticalAlignment";
const char[] XmNclientData = "clientData";
const char[] XmNclipWindow = "clipWindow";
const char[] XmNcolumns = "columns";
const char[] XmNcommand = "command";
const char[] XmNcommandChangedCallback = "commandChangedCallback";
const char[] XmNcommandEnteredCallback = "commandEnteredCallback";
const char[] XmNcommandWindow = "commandWindow";
const char[] XmNcommandWindowLocation = "commandWindowLocation";
const char[] XmNconvertProc = "convertProc";
const char[] XmNcursorBackground = "cursorBackground";
const char[] XmNcursorForeground = "cursorForeground";
const char[] XmNcursorPosition = "cursorPosition";
const char[] XmNcursorPositionVisible = "cursorPositionVisible";
const char[] XmNdarkThreshold = "darkThreshold";
const char[] XmNdecimalPoints = "decimalPoints";
const char[] XmNdecrementCallback = "decrementCallback";
const char[] XmNdefaultActionCallback = "defaultActionCallback";
const char[] XmNdefaultButton = "defaultButton";
const char[] XmNdefaultButtonShadowThickness = "defaultButtonShadowThickness";
const char[] XmNdefaultButtonType = "defaultButtonType";
const char[] XmNdefaultCopyCursorIcon = "defaultCopyCursorIcon";
const char[] XmNdefaultFontList = "defaultFontList";
const char[] XmNdefaultInvalidCursorIcon = "defaultInvalidCursorIcon";
const char[] XmNdefaultLinkCursorIcon = "defaultLinkCursorIcon";
const char[] XmNdefaultMoveCursorIcon = "defaultMoveCursorIcon";
const char[] XmNdefaultNoneCursorIcon = "defaultNoneCursorIcon";
const char[] XmNdefaultPosition = "defaultPosition";
const char[] XmNdefaultSourceCursorIcon = "defaultSourceCursorIcon";
const char[] XmNdefaultValidCursorIcon = "defaultValidCursorIcon";
const char[] XmNdeleteResponse = "deleteResponse";
const char[] XmNdesktopParent = "desktopParent";
const char[] XmNdialogStyle = "dialogStyle";
const char[] XmNdialogTitle = "dialogTitle";
const char[] XmNdialogType = "dialogType";
const char[] XmNdirListItemCount = "dirListItemCount";
const char[] XmNdirListItems = "dirListItems";
const char[] XmNdirListLabelString = "dirListLabelString";
const char[] XmNdirMask = "dirMask";
const char[] XmNdirSearchProc = "dirSearchProc";
const char[] XmNdirSpec = "dirSpec";
const char[] XmNdirectory = "directory";
const char[] XmNdirectoryValid = "directoryValid";
const char[] XmNdisarmCallback = "disarmCallback";
const char[] XmNdoubleClickInterval = "doubleClickInterval";
const char[] XmNdragCallback = "dragCallback";
const char[] XmNdragContextClass = "dragContextClass";
const char[] XmNdragDropFinishCallback = "dragDropFinishCallback";
const char[] XmNdragIconClass = "dragIconClass";
const char[] XmNdragInitiatorProtocolStyle = "dragInitiatorProtocolStyle";
const char[] XmNdragMotionCallback = "dragMotionCallback";
const char[] XmNdragOperations = "dragOperations";
const char[] XmNdragOverMode = "dragOverMode";
const char[] XmNdragProc = "dragProc";
const char[] XmNdragReceiverProtocolStyle = "dragReceiverProtocolStyle";
const char[] XmNdropFinishCallback = "dropFinishCallback";
const char[] XmNdropProc = "dropProc";
const char[] XmNdropRectangles = "dropRectangles";
const char[] XmNdropSiteActivity = "dropSiteActivity";
const char[] XmNdropSiteEnterCallback = "dropSiteEnterCallback";
const char[] XmNdropSiteLeaveCallback = "dropSiteLeaveCallback";
const char[] XmNdropSiteManagerClass = "dropSiteManagerClass";
const char[] XmNdropSiteOperations = "dropSiteOperations";
const char[] XmNdropSiteType = "dropSiteType";
const char[] XmNdropStartCallback = "dropStartCallback";
const char[] XmNdropTransferClass = "dropTransferClass";
const char[] XmNdropTransfers = "dropTransfers";
const char[] XmNeditMode = "editMode";
const char[] XmNeditable = "editable";
const char[] XmNentryAlignment = "entryAlignment";
const char[] XmNentryBorder = "entryBorder";
const char[] XmNentryCallback = "entryCallback";
const char[] XmNentryClass = "entryClass";
const char[] XmNentryVerticalAlignment = "entryVerticalAlignment";
const char[] XmNexportTargets = "exportTargets";
const char[] XmNexposeCallback = "exposeCallback";
const char[] XmNextendedSelectionCallback = "extendedSelectionCallback";
const char[] XmNextensionType = "extensionType";
const char[] XmNfileListItemCount = "fileListItemCount";
const char[] XmNfileListItems = "fileListItems";
const char[] XmNfileListLabelString = "fileListLabelString";
const char[] XmNfileSearchProc = "fileSearchProc";
const char[] XmNfileTypeMask = "fileTypeMask";
const char[] XmNfillOnArm = "fillOnArm";
const char[] XmNfillOnSelect = "fillOnSelect";
const char[] XmNfilterLabelString = "filterLabelString";
const char[] XmNfocusCallback = "focusCallback";
const char[] XmNfocusMovedCallback = "focusMovedCallback";
const char[] XmNfocusPolicyChanged = "focusPolicyChanged";
const char[] XmNfontList = "fontList";
const char[] XmNforegroundThreshold = "foregroundThreshold";
const char[] XmNfractionBase = "fractionBase";
const char[] XmNgainPrimaryCallback = "gainPrimaryCallback";
const char[] XmNhelpCallback = "helpCallback";
const char[] XmNhelpLabelString = "helpLabelString";
const char[] XmNhighlightColor = "highlightColor";
const char[] XmNhighlightOnEnter = "highlightOnEnter";
const char[] XmNhighlightPixmap = "highlightPixmap";
const char[] XmNhighlightThickness = "highlightThickness";
const char[] XmNhistoryItemCount = "historyItemCount";
const char[] XmNhistoryItems = "historyItems";
const char[] XmNhistoryMaxItems = "historyMaxItems";
const char[] XmNhistoryVisibleItemCount = "historyVisibleItemCount";
const char[] XmNhorizontalFontUnit = "horizontalFontUnit";
const char[] XmNhorizontalScrollBar = "horizontalScrollBar";
const char[] XmNhorizontalSpacing = "horizontalSpacing";
const char[] XmNhotX = "hotX";
const char[] XmNhotY = "hotY";
const char[] XmNiccHandle = "iccHandle";
const char[] XmNimportTargets = "importTargets";
const char[] XmNincrement = "increment";
const char[] XmNincrementCallback = "incrementCallback";
const char[] XmNincremental = "incremental";
const char[] XmNindicatorOn = "indicatorOn";
const char[] XmNindicatorSize = "indicatorSize";
const char[] XmNindicatorType = "indicatorType";
const char[] XmNinitialDelay = "initialDelay";
const char[] XmNinitialFocus = "initialFocus";
const char[] XmNinputCallback = "inputCallback";
const char[] XmNinputCreate = "inputCreate";
const char[] XmNinputMethod = "inputMethod";
const char[] XmNinvalidCursorForeground = "invalidCursorForeground";
const char[] XmNisAligned = "isAligned";
const char[] XmNisHomogeneous = "isHomogeneous";
const char[] XmNitemCount = "itemCount";
const char[] XmNitems = "items";
const char[] XmNkeyboardFocusPolicy = "keyboardFocusPolicy";
const char[] XmNlabelFontList = "labelFontList";
const char[] XmNlabelInsensitivePixmap = "labelInsensitivePixmap";
const char[] XmNlabelPixmap = "labelPixmap";
const char[] XmNlabelString = "labelString";
const char[] XmNlabelType = "labelType";
const char[] XmNleftAttachment = "leftAttachment";
const char[] XmNleftOffset = "leftOffset";
const char[] XmNleftPosition = "leftPosition";
const char[] XmNleftWidget = "leftWidget";
const char[] XmNlightThreshold = "lightThreshold";
const char[] XmNlineSpace = "lineSpace";
const char[] XmNlistItemCount = "listItemCount";
const char[] XmNlistItems = "listItems";
const char[] XmNlistLabelString = "listLabelString";
const char[] XmNlistMarginHeight = "listMarginHeight";
const char[] XmNlistMarginWidth = "listMarginWidth";
const char[] XmNlistSizePolicy = "listSizePolicy";
const char[] XmNlistSpacing = "listSpacing";
const char[] XmNlistUpdated = "listUpdated";
const char[] XmNlistVisibleItemCount = "listVisibleItemCount";
const char[] XmNlogicalParent = "logicalParent";
const char[] XmNlosePrimaryCallback = "losePrimaryCallback";
const char[] XmNlosingFocusCallback = "losingFocusCallback";
const char[] XmNmainWindowMarginHeight = "mainWindowMarginHeight";
const char[] XmNmainWindowMarginWidth = "mainWindowMarginWidth";
const char[] XmNmapCallback = "mapCallback";
const char[] XmNmappingDelay = "mappingDelay";
const char[] XmNmargin = "margin";
const char[] XmNmarginBottom = "marginBottom";
const char[] XmNmarginHeight = "marginHeight";
const char[] XmNmarginLeft = "marginLeft";
const char[] XmNmarginRight = "marginRight";
const char[] XmNmarginTop = "marginTop";
const char[] XmNmarginWidth = "marginWidth";
const char[] XmNmask = "mask";
const char[] XmNmaxLength = "maxLength";
const char[] XmNmaximum = "maximum";
const char[] XmNmenuAccelerator = "menuAccelerator";
const char[] XmNmenuBar = "menuBar";
const char[] XmNmenuCursor = "menuCursor";
const char[] XmNmenuHelpWidget = "menuHelpWidget";
const char[] XmNmenuHistory = "menuHistory";
const char[] XmNmenuPost = "menuPost";
const char[] XmNmessageAlignment = "messageAlignment";
const char[] XmNmessageProc = "messageProc";
const char[] XmNmessageString = "messageString";
const char[] XmNmessageWindow = "messageWindow";
const char[] XmNminimizeButtons = "minimizeButtons";
const char[] XmNminimum = "minimum";
const char[] XmNmnemonic = "mnemonic";
const char[] XmNmnemonicCharSet = "mnemonicCharSet";
const char[] XmNmodifyVerifyCallback = "modifyVerifyCallback";
const char[] XmNmodifyVerifyCallbackWcs = "modifyVerifyCallbackWcs";
const char[] XmNmotionVerifyCallback = "motionVerifyCallback";
const char[] XmNmoveOpaque = "moveOpaque";
const char[] XmNmultiClick = "multiClick";
const char[] XmNmultipleSelectionCallback = "multipleSelectionCallback";
const char[] XmNmustMatch = "mustMatch";
const char[] XmNmwmDecorations = "mwmDecorations";
const char[] XmNmwmFunctions = "mwmFunctions";
const char[] XmNmwmInputMode = "mwmInputMode";
const char[] XmNmwmMenu = "mwmMenu";
const char[] XmNmwmMessages = "mwmMessages";
const char[] XmNnavigationType = "navigationType";
const char[] XmNneedsMotion = "needsMotion";
const char[] XmNnoMatchCallback = "noMatchCallback";
const char[] XmNnoMatchString = "noMatchString";
const char[] XmNnoResize = "noResize";
const char[] XmNnoneCursorForeground = "noneCursorForeground";
const char[] XmNnotifyProc = "notifyProc";
const char[] XmNnumColumns = "numColumns";
const char[] XmNnumDropRectangles = "numDropRectangles";
const char[] XmNnumDropTransfers = "numDropTransfers";
const char[] XmNnumExportTargets = "numExportTargets";
const char[] XmNnumImportTargets = "numImportTargets";
const char[] XmNnumRectangles = "numRectangles";
const char[] XmNoffsetX = "offsetX";
const char[] XmNoffsetY = "offsetY";
const char[] XmNokCallback = "okCallback";
const char[] XmNokLabelString = "okLabelString";
const char[] XmNoperationChangedCallback = "operationChangedCallback";
const char[] XmNoperationCursorIcon = "operationCursorIcon";
const char[] XmNoptionLabel = "optionLabel";
const char[] XmNoptionMnemonic = "optionMnemonic";
const char[] XmNoutputCreate = "outputCreate";
const char[] XmNpacking = "packing";
const char[] XmNpageDecrementCallback = "pageDecrementCallback";
const char[] XmNpageIncrement = "pageIncrement";
const char[] XmNpageIncrementCallback = "pageIncrementCallback";
const char[] XmNpaneMaximum = "paneMaximum";
const char[] XmNpaneMinimum = "paneMinimum";
const char[] XmNpattern = "pattern";
const char[] XmNpendingDelete = "pendingDelete";
const char[] XmNpopupEnabled = "popupEnabled";
const char[] XmNpositionIndex = "positionIndex";
const char[] XmNpostFromButton = "postFromButton";
const char[] XmNpostFromCount = "postFromCount";
const char[] XmNpostFromList = "postFromList";
const char[] XmNpreeditType = "preeditType";
const char[] XmNprocessingDirection = "processingDirection";
const char[] XmNpromptString = "promptString";
const char[] XmNprotocolCallback = "protocolCallback";
const char[] XmNpushButtonEnabled = "pushButtonEnabled";
const char[] XmNqualifySearchDataProc = "qualifySearchDataProc";
const char[] XmNradioAlwaysOne = "radioAlwaysOne";
const char[] XmNradioBehavior = "radioBehavior";
const char[] XmNrealizeCallback = "realizeCallback";
const char[] XmNrecomputeSize = "recomputeSize";
const char[] XmNrectangles = "rectangles";
const char[] XmNrefigureMode = "refigureMode";
const char[] XmNrepeatDelay = "repeatDelay";
const char[] XmNresizable = "resizable";
const char[] XmNresizeCallback = "resizeCallback";
const char[] XmNresizeHeight = "resizeHeight";
const char[] XmNresizePolicy = "resizePolicy";
const char[] XmNresizeWidth = "resizeWidth";
const char[] XmNrightAttachment = "rightAttachment";
const char[] XmNrightOffset = "rightOffset";
const char[] XmNrightPosition = "rightPosition";
const char[] XmNrightWidget = "rightWidget";
const char[] XmNrowColumnType = "rowColumnType";
const char[] XmNrows = "rows";
const char[] XmNrubberPositioning = "rubberPositioning";
const char[] XmNsashHeight = "sashHeight";
const char[] XmNsashIndent = "sashIndent";
const char[] XmNsashShadowThickness = "sashShadowThickness";
const char[] XmNsashWidth = "sashWidth";
const char[] XmNscaleHeight = "scaleHeight";
const char[] XmNscaleMultiple = "scaleMultiple";
const char[] XmNscaleWidth = "scaleWidth";
const char[] XmNscrollBarDisplayPolicy = "scrollBarDisplayPolicy";
const char[] XmNscrollBarPlacement = "scrollBarPlacement";
const char[] XmNscrollHorizontal = "scrollHorizontal";
const char[] XmNscrollLeftSide = "scrollLeftSide";
const char[] XmNscrollTopSide = "scrollTopSide";
const char[] XmNscrollVertical = "scrollVertical";
const char[] XmNscrolledWindowMarginHeight = "scrolledWindowMarginHeight";
const char[] XmNscrolledWindowMarginWidth = "scrolledWindowMarginWidth";
const char[] XmNscrollingPolicy = "scrollingPolicy";
const char[] XmNselectColor = "selectColor";
const char[] XmNselectInsensitivePixmap = "selectInsensitivePixmap";
const char[] XmNselectPixmap = "selectPixmap";
const char[] XmNselectThreshold = "selectThreshold";
const char[] XmNselectedItemCount = "selectedItemCount";
const char[] XmNselectedItems = "selectedItems";
const char[] XmNselectionArrayCount = "selectionArrayCount";
const char[] XmNselectionLabelString = "selectionLabelString";
const char[] XmNselectionPolicy = "selectionPolicy";
const char[] XmNseparatorOn = "separatorOn";
const char[] XmNseparatorType = "separatorType";
const char[] XmNset = "set";
const char[] XmNshadow = "shadow";
const char[] XmNshadowThickness = "shadowThickness";
const char[] XmNshadowType = "shadowType";
const char[] XmNshellUnitType = "shellUnitType";
const char[] XmNshowArrows = "showArrows";
const char[] XmNshowAsDefault = "showAsDefault";
const char[] XmNshowSeparator = "showSeparator";
const char[] XmNshowValue = "showValue";
const char[] XmNsimpleCallback = "simpleCallback";
const char[] XmNsingleSelectionCallback = "singleSelectionCallback";
const char[] XmNsizePolicy = "sizePolicy";
const char[] XmNskipAdjust = "skipAdjust";
const char[] XmNsliderSize = "sliderSize";
const char[] XmNsource = "source";
const char[] XmNsourceCursorIcon = "sourceCursorIcon";
const char[] XmNsourceIsExternal = "sourceIsExternal";
const char[] XmNsourcePixmapIcon = "sourcePixmapIcon";
const char[] XmNsourceWidget = "sourceWidget";
const char[] XmNsourceWindow = "sourceWindow";
const char[] XmNspacing = "spacing";
const char[] XmNspotLocation = "spotLocation";
const char[] XmNstartTime = "startTime";
const char[] XmNstateCursorIcon = "stateCursorIcon";
const char[] XmNstringDirection = "stringDirection";
const char[] XmNsubMenuId = "subMenuId";
const char[] XmNsymbolPixmap = "symbolPixmap";
const char[] XmNtearOffMenuActivateCallback = "tearOffMenuActivateCallback";
const char[] XmNtearOffMenuDeactivateCallback = "tearOffMenuDeactivateCallback";
const char[] XmNtearOffModel = "tearOffModel";
const char[] XmNtextAccelerators = "textAccelerators";
const char[] XmNtextColumns = "textColumns";
const char[] XmNtextFontList = "textFontList";
const char[] XmNtextString = "textString";
const char[] XmNtextTranslations = "textTranslations";
const char[] XmNtextValue = "textValue";
const char[] XmNtitleString = "titleString";
const char[] XmNtoBottomCallback = "toBottomCallback";
const char[] XmNtoPositionCallback = "toPositionCallback";
const char[] XmNtoTopCallback = "toTopCallback";
const char[] XmNtopAttachment = "topAttachment";
const char[] XmNtopCharacter = "topCharacter";
const char[] XmNtopItemPosition = "topItemPosition";
const char[] XmNtopLevelEnterCallback = "topLevelEnterCallback";
const char[] XmNtopLevelLeaveCallback = "topLevelLeaveCallback";
const char[] XmNtopOffset = "topOffset";
const char[] XmNtopPosition = "topPosition";
const char[] XmNtopShadowColor = "topShadowColor";
const char[] XmNtopShadowPixmap = "topShadowPixmap";
const char[] XmNtopWidget = "topWidget";
const char[] XmNtransferProc = "transferProc";
const char[] XmNtransferStatus = "transferStatus";
const char[] XmNtraversalCallback = "traversalCallback";
const char[] XmNtraversalOn = "traversalOn";
const char[] XmNtraversalType = "traversalType";
const char[] XmNtraverseObscuredCallback = "traverseObscuredCallback";
const char[] XmNtreeUpdateProc = "treeUpdateProc";
const char[] XmNtroughColor = "troughColor";
const char[] XmNunitType = "unitType";
const char[] XmNunmapCallback = "unmapCallback";
const char[] XmNunpostBehavior = "unpostBehavior";
const char[] XmNunselectPixmap = "unselectPixmap";
const char[] XmNupdateSliderSize = "updateSliderSize";
const char[] XmNuseAsyncGeometry = "useAsyncGeometry";
const char[] XmNuserData = "userData";
const char[] XmNvalidCursorForeground = "validCursorForeground";
const char[] XmNvalueChangedCallback = "valueChangedCallback";
const char[] XmNvalueWcs = "valueWcs";
const char[] XmNverifyBell = "verifyBell";
const char[] XmNverticalFontUnit = "verticalFontUnit";
const char[] XmNverticalScrollBar = "verticalScrollBar";
const char[] XmNverticalSpacing = "verticalSpacing";
const char[] XmNvisibleItemCount = "visibleItemCount";
const char[] XmNvisibleWhenOff = "visibleWhenOff";
const char[] XmNvisualPolicy = "visualPolicy";
const char[] XmNwhichButton = "whichButton";
const char[] XmNwordWrap = "wordWrap";
const char[] XmNworkWindow = "workWindow";
const char[] XmRAlignment = "Alignment";
const char[] XmRAnimationMask = "AnimationMask";
const char[] XmRAnimationPixmap = "AnimationPixmap";
const char[] XmRAnimationStyle = "AnimationStyle";
const char[] XmRArrowDirection = "ArrowDirection";
const char[] XmRAtomList = "AtomList";
const char[] XmRAttachment = "Attachment";
const char[] XmRAudibleWarning = "AudibleWarning";
const char[] XmRAvailability = "Availability";
const char[] XmRBackgroundPixmap = "BackgroundPixmap";
const char[] XmRBlendModel = "BlendModel";
const char[] XmRBooleanDimension = "BooleanDimension";
const char[] XmRBottomShadowPixmap = "BottomShadowPixmap";
const char[] XmRButtonType = "ButtonType";
const char[] XmRCallbackProc = "CallbackProc";
const char[] XmRChar = "Char";
const char[] XmRCharSetTable = "CharSetTable";
const char[] XmRChildHorizontalAlignment = "ChildHorizontalAlignment";
const char[] XmRChildPlacement = "ChildPlacement";
const char[] XmRChildType = "ChildType";
const char[] XmRChildVerticalAlignment = "ChildVerticalAlignment";
const char[] XmRCommandWindowLocation = "CommandWindowLocation";
const char[] XmRCompoundText = "CompoundText";
const char[] XmRDefaultButtonType = "DefaultButtonType";
const char[] XmRDeleteResponse = "DeleteResponse";
const char[] XmRDialogStyle = "DialogStyle";
const char[] XmRDialogType = "DialogType";
const char[] XmRDoubleClickInterval = "DoubleClickInterval";
const char[] XmRDragInitiatorProtocolStyle = "DragInitiatorProtocolStyle";
const char[] XmRDragReceiverProtocolStyle = "DragReceiverProtocolStyle";
const char[] XmRDropSiteActivity = "DropSiteActivity";
const char[] XmRDropSiteOperations = "DropSiteOperations";
const char[] XmRDropSiteType = "DropSiteType";
const char[] XmRDropTransfers = "DropTransfers";
const char[] XmRExtensionType = "ExtensionType";
const char[] XmRFileTypeMask = "FileTypeMask";
const char[] XmRFontList = "FontList";
const char[] XmRGadgetPixmap = "GadgetPixmap";
const char[] XmRHighlightPixmap = "HighlightPixmap";
const char[] XmRHorizontalDimension = "HorizontalDimension";
const char[] XmRHorizontalInt = "HorizontalInt";
const char[] XmRHorizontalPosition = "HorizontalPosition";
const char[] XmRIconAttachment = "IconAttachment";
const char[] XmRImportTargets = "ImportTargets";
const char[] XmRIndicatorType = "IndicatorType";
const char[] XmRItemCount = "ItemCount";
const char[] XmRItems = "Items";
const char[] XmRKeySym = "KeySym";
const char[] XmRKeySymTable = "KeySymTable";
const char[] XmRKeyboardFocusPolicy = "KeyboardFocusPolicy";
const char[] XmRLabelType = "LabelType";
const char[] XmRListMarginHeight = "ListMarginHeight";
const char[] XmRListMarginWidth = "ListMarginWidth";
const char[] XmRListSizePolicy = "ListSizePolicy";
const char[] XmRListSpacing = "ListSpacing";
const char[] XmRManBottomShadowPixmap = "ManBottomShadowPixmap";
const char[] XmRManForegroundPixmap = "ManForegroundPixmap";
const char[] XmRManHighlightPixmap = "ManHighlightPixmap";
const char[] XmRManTopShadowPixmap = "ManTopShadowPixmap";
const char[] XmRMenuWidget = "MenuWidget";
const char[] XmRMnemonic = "Mnemonic";
const char[] XmRMultiClick = "MultiClick";
const char[] XmRNavigationType = "NavigationType";
const char[] XmRPacking = "Packing";
const char[] XmRPrimForegroundPixmap = "PrimForegroundPixmap";
const char[] XmRProc = "Proc";
const char[] XmRProcessingDirection = "ProcessingDirection";
const char[] XmRRectangleList = "RectangleList";
const char[] XmRResizePolicy = "ResizePolicy";
const char[] XmRRowColumnType = "RowColumnType";
const char[] XmRScrollBarDisplayPolicy = "ScrollBarDisplayPolicy";
const char[] XmRScrollBarPlacement = "ScrollBarPlacement";
const char[] XmRScrollingPolicy = "ScrollingPolicy";
const char[] XmRSelectedItemCount = "SelectedItemCount";
const char[] XmRSelectedItems = "SelectedItems";
const char[] XmRSelectionPolicy = "SelectionPolicy";
const char[] XmRSelectionType = "SelectionType";
const char[] XmRSeparatorType = "SeparatorType";
const char[] XmRShadowType = "ShadowType";
const char[] XmRShellHorizDim = "ShellHorizDim";
const char[] XmRShellHorizPos = "ShellHorizPos";
const char[] XmRShellUnitType = "ShellUnitType";
const char[] XmRShellVertDim = "ShellVertDim";
const char[] XmRShellVertPos = "ShellVertPos";
const char[] XmRSizePolicy = "SizePolicy";
const char[] XmRStringDirection = "StringDirection";
const char[] XmRTearOffModel = "TearOffModel";
const char[] XmRTopShadowPixmap = "TopShadowPixmap";
const char[] XmRTransferStatus = "TransferStatus";
const char[] XmRTraversalType = "TraversalType";
const char[] XmRUnitType = "UnitType";
const char[] XmRUnpostBehavior = "UnpostBehavior";
const char[] XmRValueWcs = "ValueWcs";
const char[] XmRVerticalAlignment = "VerticalAlignment";
const char[] XmRVerticalDimension = "VerticalDimension";
const char[] XmRVerticalInt = "VerticalInt";
const char[] XmRVerticalPosition = "VerticalPosition";
const char[] XmRVirtualBinding = "VirtualBinding";
const char[] XmRVisibleItemCount = "VisibleItemCount";
const char[] XmRVisualPolicy = "VisualPolicy";
const char[] XmRWhichButton = "WhichButton";
const char[] XmRXmBackgroundPixmap = "XmBackgroundPixmap";
const char[] XmRXmString = "XmString";
const char[] XmRXmStringCharSet = "XmStringCharSet";
const char[] XmRXmStringTable = "XmStringTable";
const char[] XmVosfActivate = "osfActivate";
const char[] XmVosfAddMode = "osfAddMode";
const char[] XmVosfBackSpace = "osfBackSpace";
const char[] XmVosfBeginLine = "osfBeginLine";
const char[] XmVosfCancel = "osfCancel";
const char[] XmVosfClear = "osfClear";
const char[] XmVosfCopy = "osfCopy";
const char[] XmVosfCut = "osfCut";
const char[] XmVosfDelete = "osfDelete";
const char[] XmVosfDown = "osfDown";
const char[] XmVosfEndLine = "osfEndLine";
const char[] XmVosfHelp = "osfHelp";
const char[] XmVosfInsert = "osfInsert";
const char[] XmVosfLeft = "osfLeft";
const char[] XmVosfMenu = "osfMenu";
const char[] XmVosfMenuBar = "osfMenuBar";
const char[] XmVosfPageDown = "osfPageDown";
const char[] XmVosfPageLeft = "osfPageLeft";
const char[] XmVosfPageRight = "osfPageRight";
const char[] XmVosfPageUp = "osfPageUp";
const char[] XmVosfPaste = "osfPaste";
const char[] XmVosfPrimaryPaste = "osfPrimaryPaste";
const char[] XmVosfQuickPaste = "osfQuickPaste";
const char[] XmVosfRight = "osfRight";
const char[] XmVosfSelect = "osfSelect";
const char[] XmVosfUndo = "osfUndo";
const char[] XmVosfUp = "osfUp";
const char[] XmSFONTLIST_DEFAULT_TAG_STRING = "FONTLIST_DEFAULT_TAG_STRING";
const char[] XmSXmFONTLIST_DEFAULT_TAG_STRING = "XmFONTLIST_DEFAULT_TAG_STRING";
const char[] XmRTopItemPosition = "TopItemPosition";
const char[] XmNtearOffTitle = "tearOffTitle";
const char[] XmCTearOffTitle = "TearOffTitle";
const char[] XmNpopupHandlerCallback = "popupHandlerCallback";
const char[] XmNconvertCallback = "convertCallback";
const char[] XmNdestinationCallback = "destinationCallback";
const char[] XmNselectedItem = "selectedItem";
const char[] XmCSelectedItem = "SelectedItem";
const char[] XmNselectionCallback = "selectionCallback";
const char[] XmNmatchBehavior = "matchBehavior";
const char[] XmCMatchBehavior = "MatchBehavior";
const char[] XmNnoFontCallback = "noFontCallback";
const char[] XmNtextPath = "textPath";
const char[] XmNeditingPath = "editingPath";
const char[] XmCEditingPath = "EditingPath";
const char[] XmNbidirectionalCursor = "bidirectionalCursor";
const char[] XmCBidirectionalCursor = "BidirectionalCursor";
const char[] XmNcollapsedStatePixmap = "collapsedStatePixmap";
const char[] XmNdetailColumnHeading = "detailColumnHeading";
const char[] XmNdetailCount = "detailCount";
const char[] XmNdetailTabList = "detailTabList";
const char[] XmNexpandedStatePixmap = "expandedStatePixmap";
const char[] XmNlargeCellHeight = "largeCellHeight";
const char[] XmNlargeCellWidth = "largeCellWidth";
const char[] XmNlayoutType = "layoutType";
const char[] XmNoutlineIndentation = "outlineIndentation";
const char[] XmNoutlineLineStyle = "outlineLineStyle";
const char[] XmNprimaryOwnership = "primaryOwnership";
const char[] XmNselectionTechnique = "selectionTechnique";
const char[] XmNsmallCellHeight = "smallCellHeight";
const char[] XmNsmallCellWidth = "smallCellWidth";
const char[] XmNspatialStyle = "spatialStyle";
const char[] XmNentryParent = "entryParent";
const char[] XmNlargeIconX = "largeIconX";
const char[] XmNlargeIconY = "largeIconY";
const char[] XmNsmallIconX = "smallIconX";
const char[] XmNsmallIconY = "smallIconY";
const char[] XmCCollapsedStatePixmap = "CollapsedStatePixmap";
const char[] XmCDetailColumnHeading = "DetailColumnHeading";
const char[] XmCDetailCount = "DetailCount";
const char[] XmCDetailMask = "DetailMask";
const char[] XmCEntryViewType = "EntryViewType";
const char[] XmCLineStyle = "LineStyle";
const char[] XmCDetailTabList = "DetailTabList";
const char[] XmCExpandedStatePixmap = "ExpandedStatePixmap";
const char[] XmCIncludeModel = "IncludeModel";
const char[] XmCCellHeight = "CellHeight";
const char[] XmCCellWidth = "CellWidth";
const char[] XmCLayoutType = "LayoutType";
const char[] XmCOutlineIndentation = "OutlineIndentation";
const char[] XmCPlaceModel = "PlaceModel";
const char[] XmCPrimaryOwnership = "PrimaryOwnership";
const char[] XmCSelectionTechnique = "SelectionTechnique";
const char[] XmCSpatialStyle = "SpatialStyle";
const char[] XmCEntryDetail = "EntryDetail";
const char[] XmCExpandState = "ExpandState";
const char[] XmNlargeIcon = "largeIcon";
const char[] XmNlargeIconMask = "largeIconMask";
const char[] XmNlargeIconPixmap = "largeIconPixmap";
const char[] XmNsmallIcon = "smallIcon";
const char[] XmNsmallIconMask = "smallIconMask";
const char[] XmNsmallIconPixmap = "smallIconPixmap";
const char[] XmCIcon = "Icon";
const char[] XmCViewType = "ViewType";
const char[] XmCVisualEmphasis = "VisualEmphasis";
const char[] XmNcurrentPageNumber = "currentPageNumber";
const char[] XmNfirstPageNumber = "firstPageNumber";
const char[] XmNlastPageNumber = "lastPageNumber";
const char[] XmNbackPagePlacement = "backPagePlacement";
const char[] XmNbackPageNumber = "backPageNumber";
const char[] XmNbackPageSize = "backPageSize";
const char[] XmNbackPageForeground = "backPageForeground";
const char[] XmNbackPageBackground = "backPageBackground";
const char[] XmNframeBackground = "frameBackground";
const char[] XmNbindingType = "bindingType";
const char[] XmNbindingPixmap = "bindingPixmap";
const char[] XmNbindingWidth = "bindingWidth";
const char[] XmNmajorTabSpacing = "majorTabSpacing";
const char[] XmNminorTabSpacing = "minorTabSpacing";
const char[] XmNinnerMarginWidth = "innerMarginWidth";
const char[] XmNinnerMarginHeight = "innerMarginHeight";
const char[] XmNframeShadowThickness = "frameShadowThickness";
const char[] XmNpageNumber = "pageNumber";
const char[] XmCCurrentPageNumber = "CurrentPageNumber";
const char[] XmCFirstPageNumber = "FirstPageNumber";
const char[] XmCLastPageNumber = "LastPageNumber";
const char[] XmCBackPagePlacement = "BackPagePlacement";
const char[] XmCBackPageNumber = "BackPageNumber";
const char[] XmCBackPageSize = "BackPageSize";
const char[] XmCBackPageForeground = "BackPageForeground";
const char[] XmCBackPageBackground = "BackPageBackground";
const char[] XmCFrameBackground = "FrameBackground";
const char[] XmCBindingType = "BindingType";
const char[] XmCBindingPixmap = "BindingPixmap";
const char[] XmCBindingWidth = "BindingWidth";
const char[] XmCMajorTabSpacing = "MajorTabSpacing";
const char[] XmCMinorTabSpacing = "MinorTabSpacing";
const char[] XmCInnerMarginWidth = "InnerMarginWidth";
const char[] XmCInnerMarginHeight = "InnerMarginHeight";
const char[] XmCPageChangeCallback = "PageChangeCallback";
const char[] XmCPageNumber = "PageNumber";
const char[] XmRArrowLayout = "ArrowLayout";
const char[] XmRArrowSensitivity = "ArrowSensitivity";
const char[] XmRSpinBoxChildType = "SpinBoxChildType";
const char[] XmNarrowLayout = "arrowLayout";
const char[] XmCArrowLayout = "ArrowLayout";
const char[] XmNarrowSensitivity = "arrowSensitivity";
const char[] XmCArrowSensitivity = "ArrowSensitivity";
const char[] XmNdefaultArrowSensitivity = "defaultArrowSensitivity";
const char[] XmCDefaultArrowSensitivity = "DefaultArrowSensitivity";
const char[] XmNarrowSize = "arrowSize";
const char[] XmCArrowSize = "ArrowSize";
const char[] XmNspinBoxChildType = "spinBoxChildType";
const char[] XmCSpinBoxChildType = "SpinBoxChildType";
const char[] XmNposition = "position";
const char[] XmNnumValues = "numValues";
const char[] XmCNumValues = "NumValues";
const char[] XmNvalues = "values";
const char[] XmCValues = "Values";
const char[] XmNminimumValue = "minimumValue";
const char[] XmCMinimumValue = "MinimumValue";
const char[] XmNmaximumValue = "maximumValue";
const char[] XmCMaximumValue = "MaximumValue";
const char[] XmNincrementValue = "incrementValue";
const char[] XmCIncrementValue = "IncrementValue";
const char[] XmRAutomaticSelection = "AutomaticSelection";
const char[] XmRLineStyle = "LineStyle";
const char[] XmREntryViewType = "EntryViewType";
const char[] XmRDirection = "Direction";
const char[] XmRLayoutType = "LayoutType";
const char[] XmRPrimaryOwnership = "PrimaryOwnership";
const char[] XmRSelectionTechnique = "SelectionTechnique";
const char[] XmRSpatialStyle = "SpatialStyle";
const char[] XmRTabList = "TabList";
const char[] XmRViewType = "ViewType";
const char[] XmRVisualEmphasis = "VisualEmphasis";
const char[] XmRBindingType = "BindingType";
const char[] XmRNBChildType = "NBChildType";
const char[] XmNentryViewType = "entryViewType";
const char[] XmNinsensitiveStippleBitmap = "insensitiveStippleBitmap";
const char[] XmNlayoutDirection = "layoutDirection";
const char[] XmNviewType = "viewType";
const char[] XmNvisualEmphasis = "visualEmphasis";
const char[] XmCLayoutDirection = "LayoutDirection";
const char[] XmNsnapBackMultiple = "snapBackMultiple";
const char[] XmNslidingMode = "slidingMode";
const char[] XmNsliderVisual = "sliderVisual";
const char[] XmNautoDragModel = "autoDragModel";
const char[] XmNcolorCalculationProc = "colorCalculationProc";
const char[] XmNbitmapConversionModel = "bitmapConversionModel";
const char[] XmNcolorAllocationProc = "colorAllocationProc";
const char[] XmNselectionMode = "selectionMode";
const char[] XmNselectedPositions = "selectedPositions";
const char[] XmNselectedPositionCount = "selectedPositionCount";
const char[] XmCSnapBackMultiple = "SnapBackMultiple";
const char[] XmCSliderVisual = "SliderVisual";
const char[] XmCSlidingMode = "SlidingMode";
const char[] XmCAutoDragModel = "AutoDragModel";
const char[] XmCColorCalculationProc = "ColorCalculationProc";
const char[] XmCBitmapConversionModel = "BitmapConversionModel";
const char[] XmCColorAllocationProc = "ColorAllocationProc";
const char[] XmCInsensitiveStippleBitmap = "InsensitiveStippleBitmap";
const char[] XmCSelectionMode = "SelectionMode";
const char[] XmCSelectedPositions = "SelectedPositions";
const char[] XmCSelectedPositionCount = "SelectedPositionCount";
const char[] XmRSlidingMode = "SlidingMode";
const char[] XmRShowArrows = "ShowArrows";
const char[] XmRSliderVisual = "SliderVisual";
const char[] XmRShowValue = "ShowValue";
const char[] XmRAutoDragModel = "AutoDragModel";
const char[] XmRSWChildType = "SWChildType";
const char[] XmRBitmapConversionModel = "BitmapConversionModel";
const char[] XmRSelectionMode = "SelectionMode";
const char[] XmNinputPolicy = "inputPolicy";
const char[] XmCInputPolicy = "InputPolicy";
const char[] XmRInputPolicy = "InputPolicy";
const char[] XmNtoggleMode = "toggleMode";
const char[] XmCToggleMode = "ToggleMode";
const char[] XmRToggleMode = "ToggleMode";
const char[] XmRIndicatorOn = "IndicatorOn";
const char[] XmRSet = "Set";
const char[] XmNindeterminatePixmap = "indeterminatePixmap";
const char[] XmCIndeterminatePixmap = "IndeterminatePixmap";
const char[] XmNunselectColor = "unselectColor";
const char[] XmCUnselectColor = "UnselectColor";
const char[] XmNselectedPosition = "selectedPosition";
const char[] XmNarrowSpacing = "arrowSpacing";
const char[] XmCArrowSpacing = "ArrowSpacing";
const char[] XmRMatchBehavior = "MatchBehavior";
const char[] XmRComboBoxType = "ComboBoxType";
const char[] XmCSelectedPosition = "SelectedPosition";
const char[] XmNenableWarp = "enableWarp";
const char[] XmCEnableWarp = "EnableWarp";
const char[] XmREnableWarp = "EnableWarp";
const char[] XmNmotifVersion = "motifVersion";
const char[] XmCMotifVersion = "MotifVersion";
const char[] XmNdefaultGlyphPixmap = "defaultGlyphPixmap";
const char[] XmCDefaultGlyphPixmap = "DefaultGlyphPixmap";
const char[] XmCRendition = "Rendition";
const char[] XmNtag = "tag";
const char[] XmCTag = "Tag";
const char[] XmNfontName = "fontName";
const char[] XmCFontName = "FontName";
const char[] XmNfontType = "fontType";
const char[] XmCFontType = "FontType";
const char[] XmRFontType = "FontType";
const char[] XmNloadModel = "loadModel";
const char[] XmCLoadModel = "LoadModel";
const char[] XmRLoadModel = "LoadModel";
const char[] XmNtabList = "tabList";
const char[] XmCTabList = "TabList";
const char[] XmRRenditionPixel = "RenditionPixel";
const char[] XmNunderlineType = "underlineType";
const char[] XmCUnderlineType = "UnderlineType";
const char[] XmNstrikethruType = "strikethruType";
const char[] XmCStrikethruType = "StrikethruType";
const char[] XmRLineType = "LineType";
const char[] XmNrenderTable = "renderTable";
const char[] XmCRenderTable = "RenderTable";
const char[] XmRRenderTable = "RenderTable";
const char[] XmNbuttonRenderTable = "buttonRenderTable";
const char[] XmCButtonRenderTable = "ButtonRenderTable";
const char[] XmRButtonRenderTable = "ButtonRenderTable";
const char[] XmNlabelRenderTable = "labelRenderTable";
const char[] XmCLabelRenderTable = "LabelRenderTable";
const char[] XmRLabelRenderTable = "LabelRenderTable";
const char[] XmNtextRenderTable = "textRenderTable";
const char[] XmCTextRenderTable = "TextRenderTable";
const char[] XmRTextRenderTable = "TextRenderTable";
const char[] XmNdragStartCallback = "dragStartCallback";
const char[] XmNnoRenditionCallback = "noRenditionCallback";
const char[] XmSXmAS_IS = "XmAS_IS";
const char[] XmMIsWhiteSpaceMethod = "IsWhiteSpaceMethod";
const char[] XmMIsScanBreakMethod = "IsScanBreakMethod";
const char[] XmMCharDirection = "CharDirection";
const char[] XmMInitialCharsDirection = "InitialCharsDirection";
const char[] XmNpatternType = "patternType";
const char[] XmNsubstitute = "substitute";
const char[] XmNinvokeParseProc = "invokeParseProc";
const char[] XmNincludeStatus = "includeStatus";
const char[] XmVosfBackTab = "osfBackTab";
const char[] XmVosfBeginData = "osfBeginData";
const char[] XmVosfDeselectAll = "osfDeselectAll";
const char[] XmVosfEndData = "osfEndData";
const char[] XmVosfEscape = "osfEscape";
const char[] XmVosfExtend = "osfExtend";
const char[] XmVosfLeftLine = "osfLeftLine";
const char[] XmVosfNext = "osfNext";
const char[] XmVosfNextField = "osfNextField";
const char[] XmVosfNextMenu = "osfNextMenu";
const char[] XmVosfNextMinor = "osfNextMinor";
const char[] XmVosfPrevField = "osfPrevField";
const char[] XmVosfPrevMenu = "osfPrevMenu";
const char[] XmVosfPrior = "osfPrior";
const char[] XmVosfPriorMinor = "osfPriorMinor";
const char[] XmVosfReselect = "osfReselect";
const char[] XmVosfRestore = "osfRestore";
const char[] XmVosfRightLine = "osfRightLine";
const char[] XmVosfSelectAll = "osfSelectAll";
const char[] XmVosfSwitchDirection = "osfSwitchDirection";
const char[] XmNnotebookChildType = "notebookChildType";
const char[] XmCNotebookChildType = "NotebookChildType";
const char[] XmRNotebookChildType = "NotebookChildType";
const char[] XmNscrolledWindowChildType = "scrolledWindowChildType";
const char[] XmCScrolledWindowChildType = "ScrolledWindowChildType";
const char[] XmRScrolledWindowChildType = "ScrolledWindowChildType";
const char[] XmNselectedObjects = "selectedObjects";
const char[] XmCSelectedObjects = "SelectedObjects";
const char[] XmNselectedObjectCount = "selectedObjectCount";
const char[] XmCSelectedObjectCount = "SelectedObjectCount";
const char[] XmNcomboBoxType = "comboBoxType";
const char[] XmCComboBoxType = "ComboBoxType";
const char[] XmNtabValue = "tabValue";
const char[] XmNoffsetModel = "offsetModel";
const char[] XmNdecimal = "decimal";
const char[] XmNdetail = "detail";
const char[] XmCDetail = "Detail";
//  const char[] XmNdetailCount = "detailCount";
//  const char[] XmCDetailCount = "DetailCount";
const char[] XmNcontainerID = "containerID";
const char[] XmCContainerID = "ContainerID";
const char[] XmSCLIENT_WINDOW = "CLIENT_WINDOW";
const char[] XmSCLIP_TEMPORARY = "CLIP_TEMPORARY";
const char[] XmSCLIPBOARD = "CLIPBOARD";
const char[] XmSCOMPOUND_TEXT = "COMPOUND_TEXT";
const char[] XmSDELETE = "DELETE";
const char[] XmSFILE = "FILE";
const char[] XmSFILE_NAME = "FILE_NAME";
const char[] XmSINCR = "INCR";
const char[] XmSINSERT_PROPERTY = "INSERT_PROPERTY";
const char[] XmSINSERT_SELECTION = "INSERT_SELECTION";
const char[] XmSLENGTH = "LENGTH";
const char[] XmSLINK_SELECTION = "LINK_SELECTION";
const char[] XmS_MOTIF_ATOM_0 = "_MOTIF_ATOM_0";
const char[] XmS_MOTIF_BINDINGS = "_MOTIF_BINDINGS";
const char[] XmS_MOTIF_DEFAULT_BINDINGS = "_MOTIF_DEFAULT_BINDINGS";
const char[] XmS_MOTIF_CANCEL_DROP_EFFECT = "_MOTIF_CANCEL_DROP_EFFECT";
const char[] XmS_MOTIF_CLIP_HEADER = "_MOTIF_CLIP_HEADER";
const char[] XmS_MOTIF_CLIP_DATA_REQUEST = "_MOTIF_CLIP_DATA_REQUEST";
const char[] XmS_MOTIF_CLIP_DATA_DELETE = "_MOTIF_CLIP_DATA_DELETE";
const char[] XmS_MOTIF_CLIP_ITEM = "_MOTIF_CLIP_ITEM";
const char[] XmS_MOTIF_CLIP_LOCK = "_MOTIF_CLIP_LOCK";
const char[] XmS_MOTIF_CLIP_LOCK_ACCESS_VALID = "_MOTIF_CLIP_LOCK_ACCESS_VALID";
const char[] XmS_MOTIF_CLIP_MESSAGE = "_MOTIF_CLIP_MESSAGE";
const char[] XmS_MOTIF_CLIP_NEXT_ID = "_MOTIF_CLIP_NEXT_ID";
const char[] XmS_MOTIF_CLIP_TIME = "_MOTIF_CLIP_TIME";
const char[] XmS_MOTIF_CLIPBOARD_TARGETS = "_MOTIF_CLIPBOARD_TARGETS";
const char[] XmS_MOTIF_COMPOUND_STRING = "_MOTIF_COMPOUND_STRING";
const char[] XmS_MOTIF_DEFERRED_CLIPBOARD_TARGETS = "_MOTIF_DEFERRED_CLIPBOARD_TARGETS";
const char[] XmS_MOTIF_DESTINATION = "_MOTIF_DESTINATION";
const char[] XmS_MOTIF_DRAG_OFFSET = "_MOTIF_DRAG_OFFSET";
const char[] XmS_MOTIF_DROP = "_MOTIF_DROP";
const char[] XmS_MOTIF_ENCODING_REGISTRY = "_MOTIF_ENCODING_REGISTRY";
const char[] XmS_MOTIF_EXPORT_TARGETS = "_MOTIF_EXPORT_TARGETS";
const char[] XmS_MOTIF_LOSE_SELECTION = "_MOTIF_LOSE_SELECTION";
const char[] XmS_MOTIF_RENDER_TABLE = "_MOTIF_RENDER_TABLE";
const char[] XmS_MOTIF_WM_QUERY = "_MOTIF_WM_QUERY";
const char[] XmS_MOTIF_WM_ALL_CLIENTS = "_MOTIF_WM_ALL_CLIENTS";
const char[] XmSMULTIPLE = "MULTIPLE";
const char[] XmSNULL = "NULL";
const char[] XmSTARGETS = "TARGETS";
const char[] XmSTEXT = "TEXT";
const char[] XmSTIMESTAMP = "TIMESTAMP";
const char[] XmSWM_STATE = "WM_STATE";
const char[] XmSTRANSFER_SUCCESS = "XmTRANSFER_SUCCESS";
const char[] XmSTRANSFER_FAILURE = "XmTRANSFER_FAILURE";
const char[] XmNpathMode = "pathMode";
const char[] XmRPathMode = "PathMode";
const char[] XmCPathMode = "PathMode";
const char[] XmNfileFilterStyle = "fileFilterStyle";
const char[] XmRFileFilterStyle = "FileFilterStyle";
const char[] XmCFileFilterStyle = "FileFilterStyle";
const char[] XmNdirTextLabelString = "dirTextLabelString";
const char[] XmCDirTextLabelString = "DirTextLabelString";
const char[] XmNenableBtn1Transfer = "enableBtn1Transfer";
const char[] XmCEnableBtn1Transfer = "EnableBtn1Transfer";
const char[] XmNenableButtonTab = "enableButtonTab";
const char[] XmCEnableButtonTab = "EnableButtonTab";
const char[] XmNenableEtchedInMenu = "enableEtchedInMenu";
const char[] XmCEnableEtchedInMenu = "EnableEtchedInMenu";
const char[] XmNdefaultButtonEmphasis = "defaultButtonEmphasis";
const char[] XmCDefaultButtonEmphasis = "DefaultButtonEmphasis";
const char[] XmRDefaultButtonEmphasis = "DefaultButtonEmphasis";
const char[] XmNenableToggleColor = "enableToggleColor";
const char[] XmCEnableToggleColor = "EnableToggleColor";
const char[] XmNenableToggleVisual = "enableToggleVisual";
const char[] XmCEnableToggleVisual = "EnableToggleVisual";
const char[] XmNenableDragIcon = "enableDragIcon";
const char[] XmCEnableDragIcon = "EnableDragIcon";
const char[] XmNenableUnselectableDrag = "enableUnselectableDrag";
const char[] XmCEnableUnselectableDrag = "EnableUnselectableDrag";
const char[] XmNdragOverActiveMode = "dragOverActiveMode";
const char[] XmCDragOverActiveMode = "DragOverActiveMode";
const char[] XmNinstallColormap = "installColormap";
const char[] XmCInstallColormap = "InstallColormap";
const char[] XmCOwnerEvents = "OwnerEvents";
const char[] XmNownerEvents = "ownerEvents";
const char[] XmCGrabStyle = "GrabStyle";
const char[] XmNgrabStyle = "grabStyle";
const char[] XmNforegroundState = "foregroundState";
const char[] XmNbackgroundState = "backgroundState";
const char[] XmCGroundState = "GroundState";
const char[] XmRGroundState = "GroundState";
const char[] XmRSelectColor = "SelectColor";
const char[] XmRLargeIconPixmap = "LargeIconPixmap";
const char[] XmRSmallIconPixmap = "SmallIconPixmap";
const char[] XmNoutlineState = "outlineState";
const char[] XmCOutlineState = "OutlineState";
const char[] XmROutlineState = "OutlineState";
const char[] XmNspatialIncludeModel = "spatialIncludeModel";
const char[] XmCSpatialIncludeModel = "SpatialIncludeModel";
const char[] XmRSpatialIncludeModel = "SpatialIncludeModel";
const char[] XmNspatialResizeModel = "spatialResizeModel";
const char[] XmCSpatialResizeModel = "SpatialResizeModel";
const char[] XmRSpatialResizeModel = "SpatialResizeModel";
const char[] XmNspatialSnapModel = "spatialSnapModel";
const char[] XmCSpatialSnapModel = "SpatialSnapModel";
const char[] XmRSpatialSnapModel = "SpatialSnapModel";
const char[] XmNdetailColumnHeadingCount = "detailColumnHeadingCount";
const char[] XmCDetailColumnHeadingCount = "DetailColumnHeadingCount";
const char[] XmNdetailOrder = "detailOrder";
const char[] XmCDetailOrder = "DetailOrder";
const char[] XmRCardinalList = "CardinalList";
const char[] XmNdetailOrderCount = "detailOrderCount";
const char[] XmCDetailOrderCount = "DetailOrderCount";
const char[] XmNoutlineColumnWidth = "outlineColumnWidth";
const char[] XmCOutlineColumnWidth = "OutlineColumnWidth";
const char[] XmNoutlineChangedCallback = "outlineChangedCallback";
const char[] XmCOutlineChangedCallback = "OutlineChangedCallback";
const char[] XmNoutlineButtonPolicy = "outlineButtonPolicy";
const char[] XmCOutlineButtonPolicy = "OutlineButtonPolicy";
const char[] XmROutlineButtonPolicy = "OutlineButtonPolicy";
const char[] XmCDefaultVirtualBindings = "DefaultVirtualBindings";
const char[] XmNdefaultVirtualBindings = "defaultVirtualBindings";
const char[] XmCResizable = "Resizable";
const char[] XmRDynamicPixmap = "DynamicPixmap";
const char[] XmNpageChangedCallback = "pageChangedCallback";
const char[] XmNarea = "area";
const char[] XmNdetailShadowThickness = "detailShadowThickness";
const char[] XmNsliderMark = "sliderMark";
const char[] XmCSliderMark = "SliderMark";
const char[] XmRSliderMark = "SliderMark";
const char[] XmREnableBtn1Transfer = "EnableBtn1Transfer";
const char[] XmNrenditionBackground = "renditionBackground";
const char[] XmNrenditionForeground = "renditionForeground";
const char[] XmCRenditionBackground = "RenditionBackground";
const char[] XmCRenditionForeground = "RenditionForeground";
const char[] XmNindeterminateInsensitivePixmap = "indeterminateInsensitivePixmap";
const char[] XmCIndeterminateInsensitivePixmap = "IndeterminateInsensitivePixmap";
const char[] XmNframeChildType = "frameChildType";
const char[] XmCFrameChildType = "FrameChildType";
const char[] XmNtextField = "textField";
const char[] XmCTextField = "TextField";
const char[] XmNenableThinThickness = "enableThinThickness";
const char[] XmCEnableThinThickness = "EnableThinThickness";
const char[] XmNprimaryColorSetId = "primaryColorSetId";
const char[] XmCPrimaryColorSetId = "PrimaryColorSetId";
const char[] XmNsecondaryColorSetId = "secondaryColorSetId";
const char[] XmCSecondaryColorSetId = "SecondaryColorSetId";
const char[] XmNtextColorSetId = "textColorSetId";
const char[] XmCTextColorSetId = "TextColorSetId";
const char[] XmNactiveColorSetId = "activeColorSetId";
const char[] XmCActiveColorSetId = "ActiveColorSetId";
const char[] XmNinactiveColorSetId = "inactiveColorSetId";
const char[] XmCInactiveColorSetId = "InactiveColorSetId";
const char[] XmNuseColorObj = "useColorObj";
const char[] XmCUseColorObj = "UseColorObj";
const char[] XmNuseTextColor = "useTextColor";
const char[] XmCUseTextColor = "UseTextColor";
const char[] XmNuseTextColorForList = "useTextColorForList";
const char[] XmCUseTextColorForList = "UseTextColorForList";
const char[] XmNuseMask = "useMask";
const char[] XmCUseMask = "UseMask";
const char[] XmNuseMultiColorIcons = "useMultiColorIcons";
const char[] XmCUseMultiColorIcons = "UseMultiColorIcons";
const char[] XmNuseIconFileCache = "useIconFileCache";
const char[] XmCUseIconFileCache = "UseIconFileCache";
const char[] XmSPIXEL_SET = "Pixel Sets";
const char[] XmSCUSTOMIZE_DATA = "Customize Data:";
const char[] XmSCOLOR_SRV_NAME = "ColorServer";
const char[] XmNlist = "list";
const char[] XmCList = "List";
const char[] XmNarrowOrientation = "arrowOrientation";
const char[] XmCArrowOrientation = "ArrowOrientation";
const char[] XmRArrowOrientation = "ArrowOrientation";
const char[] XmNpositionType = "positionType";
const char[] XmCPositionType = "PositionType";
const char[] XmRPositionType = "PositionType";
const char[] XmNwrap = "wrap";
const char[] XmCWrap = "Wrap";
const char[] XmNpositionMode = "positionMode";
const char[] XmCPositionMode = "PositionMode";
const char[] XmRPositionMode = "PositionMode";
const char[] XmNprintOrientation = "printOrientation";
const char[] XmCPrintOrientation = "PrintOrientation";
const char[] XmNprintOrientations = "printOrientations";
const char[] XmCPrintOrientations = "PrintOrientations";
const char[] XmNprintResolution = "printResolution";
const char[] XmCPrintResolution = "PrintResolution";
const char[] XmNprintResolutions = "printResolutions";
const char[] XmCPrintResolutions = "PrintResolutions";
const char[] XmNdefaultPixmapResolution = "defaultPixmapResolution";
const char[] XmCDefaultPixmapResolution = "DefaultPixmapResolution";
const char[] XmNstartJobCallback = "startJobCallback";
const char[] XmNendJobCallback = "endJobCallback";
const char[] XmNpageSetupCallback = "pageSetupCallback";
const char[] XmNpdmNotificationCallback = "pdmNotificationCallback";
const char[] XmNminX = "minX";
const char[] XmNminY = "minY";
const char[] XmNmaxX = "maxX";
const char[] XmNmaxY = "maxY";
const char[] XmCMinX = "MinX";
const char[] XmCMinY = "MinY";
const char[] XmCMaxX = "MaxX";
const char[] XmCMaxY = "MaxY";
const char[] XmNpreeditStartCallback = "preeditStartCallback";
const char[] XmNpreeditDoneCallback = "preeditDoneCallback";
const char[] XmNpreeditDrawCallback = "preeditDrawCallback";
const char[] XmNpreeditCaretCallback = "preeditCaretCallback";
const char[] XmNverifyPreedit = "verifyPreedit";
const char[] XmCVerifyPreedit = "VerifyPreedit";
const char[] XmNenableMultiKeyBindings = "enableMultiKeyBindings";
const char[] XmCEnableMultiKeyBindings = "EnableMultiKeyBindings";
const char[] XmRButtonFontList = "ButtonFontList";
const char[] XmRLabelFontList = "LabelFontList";
const char[] XmRTextFontList = "TextFontList";
const char[] XmSPIXEL_SET_PROP = "SDT Pixel Set";
const char[] XmS50_foreground = "50_foreground";
const char[] XmSunspecified_pixmap = "unspecified_pixmap";

const char[] XmFONTLIST_DEFAULT_TAG=		XmSFONTLIST_DEFAULT_TAG_STRING;
const char[] XmFONTLIST_DEFAULT_TAG_STRING=	XmSXmFONTLIST_DEFAULT_TAG_STRING;

const char[]  XmNtransientFor= "transientFor";
const char[]  XmNallowShellResize= "allowShellResize";

