/* MinWin Peer module
 * 
 * Mixin templates to simplify peer management
 *
 * Written by Ben Hinkle and released to the public domain, as
 * explained at http://creativecommons.org/licenses/publicdomain
 * Email comments and bug reports to ben.hinkle@gmail.com
 */

module minwin.peer;

version (Windows) {
  private import minwin.mswindows;
  alias HWND PeerForAdd;
  alias PeerForAdd WindowChildPeer;
} else version (Motif) {
  private import minwin.motif;
  alias Widget PeerForAdd;
  alias PeerForAdd WindowChildPeer;
} else version (GTK) {
  private import minwin.gtk;
  alias GtkWidget* PeerForAdd;
  alias PeerForAdd WindowChildPeer;
}

// possible values for hasPeer property
enum { 
  NO_PEER,      // object has no peer
  FOREIGN_PEER, // peer is not owned by object
  OWNS_PEER     // object owns peer
}

template PeerMixin() {
  ~this() { 
    disposePeer(); 
  }
  int hasPeer;
}

template SimplePeerMixin() {
  ~this() { 
    disposePeer(); 
  }
  int hasPeer;
  void dispose() { disposePeer(); }
  void disposePeer() {
    if (hasPeer == OWNS_PEER) {
      version (Windows) {
        int ok = DeleteObject(peer);
	sysAssert(ok != false, "Failed to dispose peer Font");
      } else version (Motif) {
	assert(false);
      } else version (GTK) {
	g_object_unref(cast(GObject*)peer);
      }
    }
    hasPeer = NO_PEER;
  }
}

