/* Xlib interface
 *
 * Written by Ben Hinkle.
 * Email comments and bug reports to ben.hinkle@gmail.com
 *
 * Since portions of this file are copied from the C header files and
 * edited to be in D syntax I am including the copyright notices and
 * license instructions present in those files. The "software"
 * referred to in the notices refers only to this file x11.d and to
 * no other part of MinWin or any library or application created with
 * MinWin. I'm not sure why such a notice appears in a header file but
 * it does so I'm reproducing it here.
 */

/***********************************************************
Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts,

			All Rights Reserved

Permission to use, copy, modify, and distribute this software and its 
documentation for any purpose and without fee is hereby granted, 
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in 
supporting documentation, and that the name Digital not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.  

DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.

******************************************************************/

/*

Copyright 1987, 1988, 1994, 1998  The Open Group

Permission to use, copy, modify, distribute, and sell this software and its
documentation for any purpose is hereby granted without fee, provided that
the above copyright notice appear in all copies and that both that
copyright notice and this permission notice appear in supporting
documentation.

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of The Open Group shall not be
used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from The Open Group.

*/

module minwin.x11;

extern (C) :

alias int XID;
alias XID Pixmap;
alias XID Window;
alias XID Drawable;
alias XID Font;
alias XID Colormap;
alias XID Cursor;
//alias XID GContext; // conflicts with paint.GContext
alias XID KeySym;
alias uint Atom;
alias uint Time;
alias uint VisualID;

alias void Display; // do we need the contents?
alias void* GC;

alias int Status;
alias int Bool;
alias void* XPointer;

struct XExtData {
  int number; 
  XExtData *next;
  int (*free_private)(XExtData *extension);
  XPointer private_data;
};

struct Visual {
  XExtData *ext_data; 
  VisualID visualid; 
  int c_class;  
  uint red_mask, green_mask, blue_mask;
  int bits_per_rgb; 
  int map_entries; 
};

struct Depth {
  int depth;  
  int nvisuals;  
  Visual *visuals; 
} 
struct Screen {
  XExtData *ext_data; 
  Display *display;
  Window root;  
  int width, height; 
  int mwidth, mheight; 
  int ndepths;  
  Depth *depths;  
  int root_depth;  
  Visual *root_visual; 
  GC default_gc;  
  Colormap cmap;  
  uint white_pixel;
  uint black_pixel; 
  int max_maps, min_maps; 
  int backing_store; 
  Bool save_unders; 
  long root_input_mask; 
};

Visual *XDefaultVisual(Display* disp,int screen);
Colormap XDefaultColormap(Display* disp,int screen);
uint BlackPixelOfScreen(Screen* s){ return s.black_pixel;}
uint WhitePixelOfScreen(Screen* s){ return s.white_pixel;}

struct ScreenFormat {
  XExtData *ext_data;
  int depth;  
  int bits_per_pixel; 
  int scanline_pad; 
};

struct XSetWindowAttributes {
  Pixmap background_pixmap;
  uint background_pixel; 
  Pixmap border_pixmap; 
  uint border_pixel; 
  int bit_gravity; 
  int win_gravity; 
  int backing_store; 
  uint backing_planes;
  uint backing_pixel;
  Bool save_under; 
  int event_mask; 
  int do_not_propagate_mask;
  Bool override_redirect; 
  Colormap colormap;  
  Cursor cursor;  
};

/* flags argument in size hints */
const int USPosition =(1L << 0);
const int USSize  =(1L << 1);

const int PPosition =(1L << 2);
const int PSize  =(1L << 3);
const int PMinSize =(1L << 4);
const int PMaxSize =(1L << 5);
const int PResizeInc =(1L << 6);
const int PAspect  =(1L << 7);
const int PBaseSize =(1L << 8);
const int PWinGravity =(1L << 9);

struct XWindowChanges {
  int x, y;
  int width, height;
  int border_width;
  Window sibling;
  int stack_mode;
};

struct XWindowAttributes {
  int x, y;  
  int width, height; 
  int border_width; 
  int depth;           
  Visual *visual; 
  Window root;         
  int c_class;  
  int bit_gravity; 
  int win_gravity; 
  int backing_store; 
  uint backing_planes;
  uint backing_pixel;
  Bool save_under; 
  Colormap colormap; 
  Bool map_installed; 
  int map_state; 
  int all_event_masks; 
  int your_event_mask; 
  int do_not_propagate_mask;
  Bool override_redirect; 
  Screen *screen;  
};

Status XGetWindowAttributes(Display* disp, Window w,
			    XWindowAttributes* attr);
Status XGetGeometry(Display*,Drawable,Window*,
		    int*,int*,uint*,uint*,uint*,uint*);

enum { IsUnmapped, IsUnviewable, IsViewable };

alias void* Region;

alias int EventMask;

struct XPoint {
  short x, y;
} 
  
struct XColor {
  uint pixel;
  ushort red, green, blue;
  ubyte flags;  /* do_red, do_green, do_blue */
  ubyte pad;
} 
const int AllocNone = 0;
const int AllocAll = 1;

Colormap XCreateColormap(Display* disp,Window w,Visual* vis,int alloc);
Status XAllocColor(Display* disp,Colormap cmap, XColor* res);

Status XAllocColorCells(Display* disp,Colormap cmap,Bool cont,
    uint* masks, uint np, uint* pix,uint npix);

Status XAllocColorPlanes(Display* disp,Colormap cmap,Bool contig,
    uint* pix_r, int nc,int nr,int ng, int nb,
    uint* rm, uint* gm,uint* bm);

Status XAllocNamedColor(Display* disp,Colormap colormap,
    char* name, XColor* scr,XColor* exact);

int XFreeColormap(Display* disp,Colormap cmap);

int XFreeColors(Display* disp,Colormap cmap,
    uint* pixels, int npixels, uint planes);

struct XRectangle {
  short x, y;
  ushort width, height;
} 
struct XSegment {
  short x1, y1, x2, y2;
} 
struct XArc {
  short x, y;
  ushort width, height;
  short angle1, angle2;
}
alias XImage function(Display* display, Visual* visual,
  uint depth, int format, int offset,
  char* data, uint width,uint height,
  int bitmap_pad, int bytes_per_line) create_image_function;

struct XImage {
  int width, height;
  int xoffset;	
  int format;		
  char *data;		
  int byte_order;	
  int bitmap_unit;	
  int bitmap_bit_order;
  int bitmap_pad;	
  int depth;		
  int bytes_per_line;	
  int bits_per_pixel;	
  uint red_mask;
  uint green_mask;
  uint blue_mask;
  XPointer obdata;
  struct funcs {	
    create_image_function create_image;
    int (*destroy_image)        (XImage *);
    uint (*get_pixel)  (XImage *, int, int);
    int (*put_pixel)            (XImage *, int, int, uint);
    XImage *(*sub_image)(XImage *, int, int, uint, uint);
    int (*add_pixel)            (XImage *, int);
  }
  funcs f;
}

const int GCFunction              =(1L<<0);
const int GCPlaneMask             =(1L<<1);
const int GCForeground            =(1L<<2);
const int GCBackground            =(1L<<3);
const int GCLineWidth             =(1L<<4);
const int GCLineStyle             =(1L<<5);
const int GCCapStyle              =(1L<<6);
const int GCJoinStyle  =(1L<<7);
const int GCFillStyle  =(1L<<8);
const int GCFillRule  =(1L<<9) ;
const int GCTile   =(1L<<10);
const int GCStipple  =(1L<<11);
const int GCTileStipXOrigin =(1L<<12);
const int GCTileStipYOrigin =(1L<<13);
const int GCFont    =(1L<<14);
const int GCSubwindowMode  =(1L<<15);
const int GCGraphicsExposures     =(1L<<16);
const int GCClipXOrigin  =(1L<<17);
const int GCClipYOrigin  =(1L<<18);
const int GCClipMask  =(1L<<19);
const int GCDashOffset  =(1L<<20);
const int GCDashList  =(1L<<21);
const int GCArcMode  =(1L<<22);
const int GCLastBit  =22;

/* graphics functions, as in GC.alu */

const int GXclear	=0x0;
const int GXand		=0x1;	
const int GXandReverse	=0x2;	
const int GXcopy	=0x3;
const int GXandInverted	=0x4;	
const int GXnoop	=0x5;
const int GXxor		=0x6;	
const int GXor		=0x7;	
const int GXnor		=0x8;	
const int GXequiv	=0x9;
const int GXinvert	=0xa;	
const int GXorReverse	=0xb;	
const int GXcopyInverted =0xc;	
const int GXorInverted	=0xd;
const int GXnand	=0xe;
const int GXset		=0xf;		

/* LineStyle */

const int LineSolid	=0;
const int LineOnOffDash	=1;
const int LineDoubleDash= 2;

/* capStyle */

const int CapNotLast	=0;
const int CapButt	=1;
const int CapRound	=2;
const int CapProjecting	=3;

/* joinStyle */

const int JoinMiter	=0;
const int JoinRound	=1;
const int JoinBevel	=2;

/* fillStyle */

const int FillSolid	=0;
const int FillTiled	=1;
const int FillStippled	=2;
const int FillOpaqueStippled	=3;

/* fillRule */

const int EvenOddRule	=0;
const int WindingRule	=1;


struct XGCValues {
  int function_;
  uint plane_mask;
  uint foreground;
  uint background;
  int line_width;
  int line_style;
  int cap_style;
  int join_style;
  int fill_style;
  int fill_rule;
  int arc_mode;
  Pixmap tile;
  Pixmap stipple;
  int ts_x_origin;
  int ts_y_origin;
  Font font;
  int subwindow_mode;
  int graphics_exposures;
  int clip_x_origin;
  int clip_y_origin;
  Pixmap clip_mask;
  int dash_offset;
  char dashes;
} 

int XChangeGC(Display* disp,GC gc,uint mask,XGCValues* val);
int XSetLineAttributes(Display* disp,GC gc,uint line_width,
		       int line_style, int cap_style,int join_style);

int XSetDashes(Display* display,GC gc,int dash_offset,
    ubyte* dash_list, int n);

int XSetFillRule(Display* disp,GC gc,int fill_rule);

int XSetFillStyle(Display* disp,GC gc,int fill_style);

Region XCreateRegion();
int XDestroyRegion(Region r);
int XEmptyRegion(Region r);
int XEqualRegion(Region r1, Region r2);
int XIntersectRegion(Region sra, Region srb, Region dr_return);
int XOffsetRegion(Region r, int dx, int dy);
Bool XPointInRegion(Region r,int x, int y);
Region XPolygonRegion(XPoint* points, int n, int fill_rule);
int XSetRegion(Display* display, GC gc, Region r);
int XShrinkRegion(Region r, int dx, int dy);
int XSubtractRegion(Region sra, Region srb, Region dr_return);
int XUnionRectWithRegion(XRectangle* r, Region src_r, Region dest_r);
int XUnionRegion(Region sra, Region srb, Region dr_return);
int XXorRegion(Region sra, Region srb, Region dr_return);
int XRectInRegion(Region r, int x, int y, uint width, uint height);

int XFreePixmap(Display* display,Pixmap p);
Pixmap XCreatePixmap(Display* display,Drawable d,
		     uint width, uint height,uint depth);
Pixmap XCreateBitmapFromData(Display* display,Drawable d,
			     char* data, uint width, uint height);
Pixmap XCreatePixmapFromBitmapData(Display* display,Drawable d,
				   char* data, uint width, uint height,
				   uint fg, uint bg, uint depth);
int XReadBitmapFile(Display*,Drawable,char*,uint* width,
		    uint* height, Pixmap* bitmap, int* x_hot,int* y_hot);
Window XCreateSimpleWindow(Display* display,Window parent,
			   int x,int y, uint width, uint height,
			   uint border_width, uint border,uint ba);
Window XGetSelectionOwner(Display* display, Atom selection);
Window XCreateWindow(Display* display, Window parent, int x,int y,
		     uint width, uint height, uint border_width,
		     int depth, uint class_c, Visual* visual,
		     uint valuemask, XSetWindowAttributes* attributes); 
Colormap *XListInstalledColormaps(Display* display,Window w, int* ret);
char **XListFonts(Display* display, char* pattern,
		  int maxnames,int* actual_count_return);
char **XListFontsWithInfo(Display* display,char* pattern,
			  int maxnames, int* count_return,
			  XFontStruct** info_return);
char **XGetFontPath(Display* display, int* npaths_return);
char **XListExtensions(Display* display, int* nextensions_return);
Atom *XListProperties(Display* display, Window w,int* num_prop_return);

struct XHostAddress {
  int family;
  int length;
  char *address;
}

XHostAddress *XListHosts(Display* display,int* nhosts, Bool* state);
KeySym XKeycodeToKeysym(Display* display, uint keycode, int index);
KeySym XLookupKeysym(XKeyEvent* key_event, int index);
KeySym *XGetKeyboardMapping(Display* display, uint first_keycode,
			    int keycode_count, int* keysym);
KeySym XStringToKeysym(char* string);
long XMaxRequestSize(Display* display);
long XExtendedMaxRequestSize(Display* display);
char *XResourceManagerString(Display* display);
char *XScreenResourceString(Screen* screen);
uint XDisplayMotionBufferSize(Display* display);
VisualID XVisualIDFromVisual(Visual* visual);

void XMapWindow(Display* disp, Window w);
void XMapRaised(Display* disp, Window w);
void XUnmapWindow(Display* disp, Window w);

void XMoveResizeWindow(Display* disp, Window w, int x,int y,int w, int h);
GC XCreateGC(Display* disp, Drawable d, uint mask, XGCValues* vals);
void XFreeGC(Display* disp, GC gc);
void XFlushGC(Display* display, GC gc);
int XFlush(Display* display);
Status XGetGCValues(Display*,GC,uint,XGCValues*);
XFontStruct *XQueryFont(Display*,XID);
int XFreeFontInfo(char**,XFontStruct*,int);

struct XCharStruct {
    short	lbearing;
    short	rbearing;
    short	width;		
    short	ascent;		
    short	descent;
    ushort attributes;	
}

struct XFontProp {
    Atom name;
    uint card32;
}

struct XFontStruct {
    XExtData	*ext_data;
    Font        fid;      
    uint	direction;
    uint	min_char_or_byte2;
    uint	max_char_or_byte2;
    uint	min_byte1;	
    uint	max_byte1;	
    Bool	all_chars_exist;
    uint	default_char;	
    int         n_properties;   
    XFontProp	*properties;	
    XCharStruct	min_bounds;	
    XCharStruct	max_bounds;	
    XCharStruct	*per_char;	
    int		ascent;		
    int		descent;	
}

struct XTextItem {
    char *chars;		
    int nchars;			
    int delta;			
    Font font;			
}

struct XChar2b {		
    char byte1;
    char byte2;
}

struct XTextItem16 {
    XChar2b *chars;
    int nchars;		
    int delta;		
    Font font;		
}

union XEDataObject {
  Display *display;
  GC gc;
  Visual *visual;
  Screen *screen;
  ScreenFormat *pixmap_format;
  XFontStruct *font;
}

struct XFontSetExtents {
  XRectangle      max_ink_extent;
  XRectangle      max_logical_extent;
}

alias void* XOM;
alias void* XOC;
alias void* XFontSet;

struct XmbTextItem {
  char           *chars;
  int             nchars;
  int             delta;
  XFontSet        font_set;
};

struct XwcTextItem {
  dchar *chars;
  int nchars;
  int delta;
  XFontSet font_set;
};

Font XLoadFont(Display* disp, char* name);
void XUnloadFont(Display* disp, Font font);
int XSetFont(Display* disp, GC gc, Font font);

int XDrawString(Display* disp, Drawable d, GC gc, int x, int y, 
		char* str, int len);

int XDrawLine(Display* disp, Drawable d, GC gc,
	      int x1, int y1, int x2, int y2);

enum { CoordModeOrigin, CoordModePrevious };

int XDrawLines(Display* disp, Drawable d, GC gc,
	       XPoint* pts, int n, int mode);

int XDrawPoint(Display* disp, Drawable d, GC gc,
	       int x, int y);

int XDrawPoints(Display* disp, Drawable d, GC gc,
		XPoint* pts, int n, int mode);

int XDrawRectangle(Display* disp, Drawable d, GC gc,
		   int x, int y, uint width,uint height);

int XDrawRectangles(Display* disp, Drawable d,
		    GC gc, XRectangle* r, int n);

int XDrawSegments(Display* disp, Drawable d, GC gc,
		  XSegment* segs, int n);

int XFillArc(Display* display,Drawable d,GC gc,
	     int x, int y, uint width, uint height,
	     int angle1, int angle2);

int XFillArcs(Display* display, Drawable d, GC gc,XArc* arcs,int n);

enum { Complex, Convex, Nonconvex };

int XFillPolygon(Display* display, Drawable d, GC gc,
		 XPoint* pnts, int npnts, int shape, int mode);

int XFillRectangle(Display* display,Drawable d, GC gc,
		   int x, int y, uint width, uint height);

int XFillRectangles(Display* display,Drawable d, GC gc,
		    XRectangle* rects, int nrects);

XImage *XCreateImage(Display* display,Visual* visual, uint depth,
		     int format, int offset, char* data,
		     uint width, uint height,
		     int bitmap_pad, int bytes_per_line);

Status XInitImage(XImage* image);

XImage *XGetImage(Display* display, Drawable d, int x,
		  int y, uint width, uint height,
		  uint plane_mask, int format);

XImage *XGetSubImage(Display* display, Drawable d,
		     int x, int y, uint width, uint height,
		     uint plane_mask, int format, XImage* dest_image,
		     int dest_x, int dest_y);
int XCopyArea(Display* disp, Drawable src,
	      Drawable dest, GC gc, int src_x, int src_y,
	      uint width, uint height, int dest_x, int dest_y);

const int NoEventMask = 0;
const int KeyPressMask = (1<<0);
const int KeyReleaseMask = (1<<1); 
const int ButtonPressMask = (1<<2); 
const int ButtonReleaseMask = (1<<3) ;
const int EnterWindowMask = (1<<4);  
const int LeaveWindowMask = (1<<5);  
const int PointerMotionMask = (1<<6);  
const int PointerMotionHintMask = (1<<7);  
const int Button1MotionMask = (1<<8);  
const int Button2MotionMask = (1<<9);  
const int Button3MotionMask = (1<<10); 
const int Button4MotionMask = (1<<11); 
const int Button5MotionMask = (1<<12); 
const int ButtonMotionMask = (1<<13); 
const int KeymapStateMask = (1<<14);
const int ExposureMask = (1<<15); 
const int VisibilityChangeMask = (1<<16); 
const int StructureNotifyMask = (1<<17); 
const int ResizeRedirectMask = (1<<18); 
const int SubstructureNotifyMask = (1<<19); 
const int SubstructureRedirectMask = (1<<20); 
const int FocusChangeMask = (1<<21); 
const int PropertyChangeMask = (1<<22); 
const int ColormapChangeMask = (1<<23); 
const int OwnerGrabButtonMask = (1<<24); 
  
const int Success = 0;
const int BadRequest = 1;
const int BadValue = 2;
const int BadWindow = 3;
const int BadPixmap = 4;
const int BadAtom = 5;
const int BadCursor = 6;
const int BadFont = 7;
const int BadMatch = 8;
const int BadDrawable = 9;
const int BadAccess = 10;
const int BadAlloc = 11;
const int BadColor = 12;
const int BadGC = 13;
const int BadIDChoice = 14;
const int BadName = 15;
const int BadLength = 16;
const int BadImplementation = 17;

const int FirstExtensionError = 128;
const int LastExtensionError = 255;

struct XKeyEvent {
  int type; 
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;  
  Window root;  
  Window subwindow;
  Time time;  
  int x, y;  
  int x_root, y_root; 
  uint state; 
  uint keycode; 
  Bool same_screen;
} 

alias XKeyEvent XKeyPressedEvent;
alias XKeyEvent XKeyReleasedEvent;

struct XButtonEvent {
  int type;  
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;  
  Window root;  
  Window subwindow;
  Time time;  
  int x, y;  
  int x_root, y_root; 
  uint state; 
  uint button; 
  Bool same_screen;
};

alias XButtonEvent XButtonPressedEvent;
alias XButtonEvent XButtonReleasedEvent;

struct XMotionEvent {
  int type; 
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;  
  Window root;  
  Window subwindow;
  Time time;  
  int x, y;  
  int x_root, y_root; 
  uint state; 
  char is_hint; 
  Bool same_screen;
};
alias XMotionEvent XPointerMovedEvent;

struct XCrossingEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window window;  
  Window root;  
  Window subwindow;
  Time time;  
  int x, y;  
  int x_root, y_root; 
  int mode;  
  int detail;
  Bool same_screen;
  Bool focus;  
  uint state;
};
alias XCrossingEvent XEnterWindowEvent;
alias XCrossingEvent XLeaveWindowEvent;

struct XFocusChangeEvent {
  int type; 
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;  
  int mode;  
  int detail;
};
alias XFocusChangeEvent XFocusInEvent;
alias XFocusChangeEvent XFocusOutEvent;

/* generated on EnterWindow and FocusIn  when KeyMapState selected */
struct XKeymapEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window window;
  char key_vector[32];
};

struct XExposeEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window window;
  int x, y;
  int width, height;
  int count;  
};

struct XGraphicsExposeEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Drawable drawable;
  int x, y;
  int width, height;
  int count;  
  int major_code;
  int minor_code;
};

struct XNoExposeEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Drawable drawable;
  int major_code;  
  int minor_code;  
};

struct XVisibilityEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;
  int state;  
};

struct XCreateWindowEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window parent; 
  Window window; 
  int x, y;  
  int width, height;
  int border_width; 
  Bool override_redirect;
};

struct XDestroyWindowEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window event;
  Window window;
};

struct XUnmapEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window event;
  Window window;
  Bool from_configure;
};

struct XMapEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window event;
  Window window;
  Bool override_redirect;
};

struct XMapRequestEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window parent;
  Window window;
};

struct XReparentEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window event;
  Window window;
  Window parent;
  int x, y;
  Bool override_redirect;
};

struct XConfigureEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window event;
  Window window;
  int x, y;
  int width, height;
  int border_width;
  Window above;
  Bool override_redirect;
};

struct XGravityEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window event;
  Window window;
  int x, y;
};

struct XResizeRequestEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;
  int width, height;
};

struct XConfigureRequestEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window parent;
  Window window;
  int x, y;
  int width, height;
  int border_width;
  Window above;
  int detail; 
  uint value_mask;
};

struct XCirculateEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window event;
  Window window;
  int place;  
};

struct XCirculateRequestEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window parent;
  Window window;
  int place; 
};

struct XPropertyEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window window;
  Atom atom;
  Time time;
  int state;
};

struct XSelectionClearEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window window;
  Atom selection;
  Time time;
};

struct XSelectionRequestEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window owner;
  Window requestor;
  Atom selection;
  Atom target;
  Atom property;
  Time time;
};

struct XSelectionEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window requestor;
  Atom selection;
  Atom target;
  Atom property;  
  Time time;
};

struct XColormapEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;
  Colormap colormap;
  Bool c_new;  
  int state;  
};

struct XClientMessageEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;
  Atom message_type;
  int format;
  union U {
    char b[20];
    short s[10];
    int l[5];
  };
  U data;
};

struct XMappingEvent {
  int type;
  uint serial; 
  Bool send_event;
  Display *display;
  Window window;  
  int request;  
  int first_keycode;
  int count;
};

struct XErrorEvent {
  int type;
  Display *display;
  XID resourceid; 
  uint serial;
  char error_code;
  char request_code;
  char minor_code;
};

struct XAnyEvent {
  int type;
  uint serial;
  Bool send_event;
  Display *display;
  Window window;
};

union XEvent {
  int type;  /* must not be changed; first element */
  XAnyEvent xany;
  XKeyEvent xkey;
  XButtonEvent xbutton;
  XMotionEvent xmotion;
  XCrossingEvent xcrossing;
  XFocusChangeEvent xfocus;
  XExposeEvent xexpose;
  XGraphicsExposeEvent xgraphicsexpose;
  XNoExposeEvent xnoexpose;
  XVisibilityEvent xvisibility;
  XCreateWindowEvent xcreatewindow;
  XDestroyWindowEvent xdestroywindow;
  XUnmapEvent xunmap;
  XMapEvent xmap;
  XMapRequestEvent xmaprequest;
  XReparentEvent xreparent;
  XConfigureEvent xconfigure;
  XGravityEvent xgravity;
  XResizeRequestEvent xresizerequest;
  XConfigureRequestEvent xconfigurerequest;
  XCirculateEvent xcirculate;
  XCirculateRequestEvent xcirculaterequest;
  XPropertyEvent xproperty;
  XSelectionClearEvent xselectionclear;
  XSelectionRequestEvent xselectionrequest;
  XSelectionEvent xselection;
  XColormapEvent xcolormap;
  XClientMessageEvent xclient;
  XMappingEvent xmapping;
  XErrorEvent xerror;
  XKeymapEvent xkeymap;
  long pad[24];
};

Status XSendEvent(Display* disp, Window w, Bool prop, int mask, XEvent* ev);
int XNextRequest(Display* disp);
void XClearWindow(Display* disp, Window w);
void XClearArea(Display* disp, Window w, int x, int y, uint w, uint h, bool exp);
const int KeyPress=  2;
const int KeyRelease=  3;
const int ButtonPress=  4;
const int ButtonRelease=  5;
const int MotionNotify=  6;
const int EnterNotify=  7;
const int LeaveNotify=  8;
const int FocusIn=   9;
const int FocusOut=  10;
const int KeymapNotify=  11;
const int Expose=   12;
const int GraphicsExpose=  13;
const int NoExpose=  14;
const int VisibilityNotify= 15;
const int CreateNotify = 16;
const int DestroyNotify=  17;
const int UnmapNotify=  18;
const int MapNotify=  19;
const int MapRequest=  20;
const int ReparentNotify=  21;
const int ConfigureNotify=  22;
const int ConfigureRequest= 23;
const int GravityNotify=  24;
const int ResizeRequest = 25;
const int CirculateNotify=  26;
const int CirculateRequest= 27;
const int PropertyNotify=  28;
const int SelectionClear=  29;
const int SelectionRequest= 30;
const int SelectionNotify=  31;
const int ColormapNotify=  32;
const int ClientMessage = 33;
const int MappingNotify = 34;
const int LASTEvent=  35;

int XNextEvent(Display* disp, XEvent* ev);

/** Imlib functions **/
alias void ImlibData;
struct ImlibImage {
  int   rgb_width, rgb_height;
  char *rgb_data;
  char *alpha_data;
  char *filename;
}

ImlibData *Imlib_init(Display * disp);
ImlibImage *Imlib_load_image(ImlibData * id, char *file);
int Imlib_load_file_to_pixmap(ImlibData * id, char *filename,
			      Pixmap * pmap, Pixmap * mask);
